/* SerializableObjectModel-TDocument-Test.c generated by valac 0.44.3, the Vala compiler
 * generated from SerializableObjectModel-TDocument-Test.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */

#include <glib-object.h>
#include <glib.h>
#include <gxml/gxml.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <stdio.h>

#define TYPE_GXML_TEST (gxml_test_get_type ())
#define GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_GXML_TEST, GXmlTest))
#define GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_GXML_TEST, GXmlTestClass))
#define IS_GXML_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_GXML_TEST))
#define IS_GXML_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_GXML_TEST))
#define GXML_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_GXML_TEST, GXmlTestClass))

typedef struct _GXmlTest GXmlTest;
typedef struct _GXmlTestClass GXmlTestClass;
typedef struct _GXmlTestPrivate GXmlTestPrivate;

#define TYPE_SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST (serializable_object_model_tdocument_test_get_type ())
#define SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST, SerializableObjectModelTDocumentTest))
#define SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST, SerializableObjectModelTDocumentTestClass))
#define IS_SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST))
#define IS_SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST))
#define SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST, SerializableObjectModelTDocumentTestClass))

typedef struct _SerializableObjectModelTDocumentTest SerializableObjectModelTDocumentTest;
typedef struct _SerializableObjectModelTDocumentTestClass SerializableObjectModelTDocumentTestClass;
typedef struct _SerializableObjectModelTDocumentTestPrivate SerializableObjectModelTDocumentTestPrivate;

#define TYPE_OBJECT_MODEL (object_model_get_type ())
#define OBJECT_MODEL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_OBJECT_MODEL, ObjectModel))
#define OBJECT_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_OBJECT_MODEL, ObjectModelClass))
#define IS_OBJECT_MODEL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_OBJECT_MODEL))
#define IS_OBJECT_MODEL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_OBJECT_MODEL))
#define OBJECT_MODEL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_OBJECT_MODEL, ObjectModelClass))

typedef struct _ObjectModel ObjectModel;
typedef struct _ObjectModelClass ObjectModelClass;

#define TYPE_COMPUTER (computer_get_type ())
#define COMPUTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_COMPUTER, Computer))
#define COMPUTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_COMPUTER, ComputerClass))
#define IS_COMPUTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_COMPUTER))
#define IS_COMPUTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_COMPUTER))
#define COMPUTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_COMPUTER, ComputerClass))

typedef struct _Computer Computer;
typedef struct _ComputerClass ComputerClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define TYPE_MANUAL (manual_get_type ())
#define MANUAL(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MANUAL, Manual))
#define MANUAL_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MANUAL, ManualClass))
#define IS_MANUAL(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MANUAL))
#define IS_MANUAL_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MANUAL))
#define MANUAL_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MANUAL, ManualClass))

typedef struct _Manual Manual;
typedef struct _ManualClass ManualClass;

#define TYPE_PACKAGE (package_get_type ())
#define PACKAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PACKAGE, Package))
#define PACKAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PACKAGE, PackageClass))
#define IS_PACKAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PACKAGE))
#define IS_PACKAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PACKAGE))
#define PACKAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PACKAGE, PackageClass))

typedef struct _Package Package;
typedef struct _PackageClass PackageClass;

#define TYPE_MONITOR (monitor_get_type ())
#define MONITOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_MONITOR, Monitor))
#define MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_MONITOR, MonitorClass))
#define IS_MONITOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_MONITOR))
#define IS_MONITOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_MONITOR))
#define MONITOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_MONITOR, MonitorClass))

typedef struct _Monitor Monitor;
typedef struct _MonitorClass MonitorClass;

#define TYPE_CONFIGURATION (configuration_get_type ())
#define CONFIGURATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_CONFIGURATION, Configuration))
#define CONFIGURATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_CONFIGURATION, ConfigurationClass))
#define IS_CONFIGURATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_CONFIGURATION))
#define IS_CONFIGURATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_CONFIGURATION))
#define CONFIGURATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_CONFIGURATION, ConfigurationClass))

typedef struct _Configuration Configuration;
typedef struct _ConfigurationClass ConfigurationClass;

#define TYPE_NAME_SPACE (name_space_get_type ())
#define NAME_SPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_NAME_SPACE, NameSpace))
#define NAME_SPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_NAME_SPACE, NameSpaceClass))
#define IS_NAME_SPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_NAME_SPACE))
#define IS_NAME_SPACE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_NAME_SPACE))
#define NAME_SPACE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_NAME_SPACE, NameSpaceClass))

typedef struct _NameSpace NameSpace;
typedef struct _NameSpaceClass NameSpaceClass;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);
#define _vala_return_if_fail(expr, msg) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return; }
#define _vala_return_val_if_fail(expr, msg, val) if G_LIKELY (expr) ; else { g_return_if_fail_warning (G_LOG_DOMAIN, G_STRFUNC, msg); return val; }
#define _vala_warn_if_fail(expr, msg) if G_LIKELY (expr) ; else g_warn_message (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _GXmlTest {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GXmlTestPrivate * priv;
};

struct _GXmlTestClass {
	GTypeClass parent_class;
	void (*finalize) (GXmlTest *self);
};

struct _SerializableObjectModelTDocumentTest {
	GXmlTest parent_instance;
	SerializableObjectModelTDocumentTestPrivate * priv;
};

struct _SerializableObjectModelTDocumentTestClass {
	GXmlTestClass parent_class;
};

static gpointer serializable_object_model_tdocument_test_parent_class = NULL;

gpointer gxml_test_ref (gpointer instance);
void gxml_test_unref (gpointer instance);
GParamSpec* param_spec_gxml_test (const gchar* name,
                                  const gchar* nick,
                                  const gchar* blurb,
                                  GType object_type,
                                  GParamFlags flags);
void value_set_gxml_test (GValue* value,
                          gpointer v_object);
void value_take_gxml_test (GValue* value,
                           gpointer v_object);
gpointer value_get_gxml_test (const GValue* value);
GType gxml_test_get_type (void) G_GNUC_CONST;
GType serializable_object_model_tdocument_test_get_type (void) G_GNUC_CONST;
void serializable_object_model_tdocument_test_add_tests (void);
static void __lambda283_ (void);
GType object_model_get_type (void) G_GNUC_CONST;
GType computer_get_type (void) G_GNUC_CONST;
Computer* computer_new (void);
Computer* computer_construct (GType object_type);
static void ___lambda283__gtest_func (void);
static void __lambda284_ (void);
GType manual_get_type (void) G_GNUC_CONST;
Manual* manual_new (void);
Manual* manual_construct (GType object_type);
const gchar* manual_get_document (Manual* self);
gint manual_get_pages (Manual* self);
gchar* manual_get_contents (Manual* self);
static void ___lambda284__gtest_func (void);
static void __lambda285_ (void);
GType package_get_type (void) G_GNUC_CONST;
Package* package_new (void);
Package* package_construct (GType object_type);
static void ___lambda285__gtest_func (void);
static void __lambda286_ (void);
GArray* package_get_tags (Package* self);
static void ___lambda286__gtest_func (void);
static void __lambda287_ (void);
GType monitor_get_type (void) G_GNUC_CONST;
Monitor* monitor_new (void);
Monitor* monitor_construct (GType object_type);
void monitor_set_resolution (Monitor* self,
                             const gchar* value);
void monitor_set_ac_power (Monitor* self,
                           gint value);
void monitor_set_dc_power (Monitor* self,
                           gint value);
static void ___lambda287__gtest_func (void);
static void __lambda288_ (void);
GType configuration_get_type (void) G_GNUC_CONST;
Configuration* configuration_new (void);
Configuration* configuration_construct (GType object_type);
void configuration_set_device (Configuration* self,
                               const gchar* value);
static void ___lambda288__gtest_func (void);
static void __lambda289_ (void);
GType name_space_get_type (void) G_GNUC_CONST;
NameSpace* name_space_new (void);
NameSpace* name_space_construct (GType object_type);
static void ___lambda289__gtest_func (void);
static void __lambda290_ (void);
static void ___lambda290__gtest_func (void);
static void __lambda291_ (void);
static void ___lambda291__gtest_func (void);
SerializableObjectModelTDocumentTest* serializable_object_model_tdocument_test_new (void);
SerializableObjectModelTDocumentTest* serializable_object_model_tdocument_test_construct (GType object_type);
GXmlTest* gxml_test_new (void);
GXmlTest* gxml_test_construct (GType object_type);

static void
__lambda283_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		Computer* computer = NULL;
		Computer* _tmp0_;
		GXmlTDocument* doc = NULL;
		GXmlTDocument* _tmp1_;
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		GXmlNode* m = NULL;
		GXmlNode* _tmp12_;
		GXmlNode* _tmp13_;
		GXmlNode* _tmp14_;
		GeeMap* _tmp15_;
		GeeMap* _tmp16_;
		GeeMap* _tmp17_;
		gpointer _tmp18_;
		GXmlNode* _tmp19_;
		GXmlNode* mod = NULL;
		GXmlNode* _tmp20_;
		GXmlNode* _tmp21_;
		GXmlNode* _tmp22_;
		GeeMap* _tmp23_;
		GeeMap* _tmp24_;
		GeeMap* _tmp25_;
		gpointer _tmp26_;
		GXmlNode* _tmp27_;
		GXmlNode* c = NULL;
		GXmlNode* _tmp28_;
		GXmlNode* _tmp29_;
		GXmlNode* _tmp30_;
		GeeMap* _tmp31_;
		GeeMap* _tmp32_;
		GeeMap* _tmp33_;
		gpointer _tmp34_;
		GXmlNode* _tmp35_;
		GXmlNode* g = NULL;
		GXmlNode* _tmp36_;
		GXmlNode* _tmp37_;
		GXmlNode* _tmp38_;
		GeeMap* _tmp39_;
		GeeMap* _tmp40_;
		GeeMap* _tmp41_;
		gpointer _tmp42_;
		GXmlNode* _tmp43_;
#line 35 "SerializableObjectModel-TDocument-Test.vala"
		_tmp0_ = computer_new ();
#line 35 "SerializableObjectModel-TDocument-Test.vala"
		computer = _tmp0_;
#line 36 "SerializableObjectModel-TDocument-Test.vala"
		_tmp1_ = gxml_tdocument_new ();
#line 36 "SerializableObjectModel-TDocument-Test.vala"
		doc = _tmp1_;
#line 37 "SerializableObjectModel-TDocument-Test.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) computer, (GXmlNode*) doc, &_inner_error0_);
#line 37 "SerializableObjectModel-TDocument-Test.vala"
		_tmp3_ = _tmp2_;
#line 37 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp3_);
#line 37 "SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 37 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (doc);
#line 37 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (computer);
#line 280 "SerializableObjectModel-TDocument-Test.c"
			goto __catch337_g_error;
		}
#line 38 "SerializableObjectModel-TDocument-Test.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 38 "SerializableObjectModel-TDocument-Test.vala"
		_tmp5_ = _tmp4_;
#line 38 "SerializableObjectModel-TDocument-Test.vala"
		_tmp6_ = _tmp5_;
#line 38 "SerializableObjectModel-TDocument-Test.vala"
		_tmp7_ = gxml_node_get_name (_tmp6_);
#line 38 "SerializableObjectModel-TDocument-Test.vala"
		_tmp8_ = _tmp7_;
#line 38 "SerializableObjectModel-TDocument-Test.vala"
		_tmp9_ = _tmp8_;
#line 38 "SerializableObjectModel-TDocument-Test.vala"
		_tmp10_ = g_utf8_strdown (_tmp9_, (gssize) -1);
#line 38 "SerializableObjectModel-TDocument-Test.vala"
		_tmp11_ = _tmp10_;
#line 38 "SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (g_strcmp0 (_tmp11_, "computer") == 0, "doc.root.name.down () == \"computer\"");
#line 38 "SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp11_);
#line 38 "SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp9_);
#line 38 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp6_);
#line 39 "SerializableObjectModel-TDocument-Test.vala"
		_tmp12_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 39 "SerializableObjectModel-TDocument-Test.vala"
		_tmp13_ = _tmp12_;
#line 39 "SerializableObjectModel-TDocument-Test.vala"
		_tmp14_ = _tmp13_;
#line 39 "SerializableObjectModel-TDocument-Test.vala"
		_tmp15_ = gxml_node_get_attrs (_tmp14_);
#line 39 "SerializableObjectModel-TDocument-Test.vala"
		_tmp16_ = _tmp15_;
#line 39 "SerializableObjectModel-TDocument-Test.vala"
		_tmp17_ = _tmp16_;
#line 39 "SerializableObjectModel-TDocument-Test.vala"
		_tmp18_ = gee_map_get (_tmp17_, "manufacturer");
#line 39 "SerializableObjectModel-TDocument-Test.vala"
		_tmp19_ = (GXmlNode*) _tmp18_;
#line 39 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp17_);
#line 39 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp14_);
#line 39 "SerializableObjectModel-TDocument-Test.vala"
		m = _tmp19_;
#line 40 "SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (m != NULL, "m != null");
#line 41 "SerializableObjectModel-TDocument-Test.vala"
		_tmp20_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 41 "SerializableObjectModel-TDocument-Test.vala"
		_tmp21_ = _tmp20_;
#line 41 "SerializableObjectModel-TDocument-Test.vala"
		_tmp22_ = _tmp21_;
#line 41 "SerializableObjectModel-TDocument-Test.vala"
		_tmp23_ = gxml_node_get_attrs (_tmp22_);
#line 41 "SerializableObjectModel-TDocument-Test.vala"
		_tmp24_ = _tmp23_;
#line 41 "SerializableObjectModel-TDocument-Test.vala"
		_tmp25_ = _tmp24_;
#line 41 "SerializableObjectModel-TDocument-Test.vala"
		_tmp26_ = gee_map_get (_tmp25_, "model");
#line 41 "SerializableObjectModel-TDocument-Test.vala"
		_tmp27_ = (GXmlNode*) _tmp26_;
#line 41 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp25_);
#line 41 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp22_);
#line 41 "SerializableObjectModel-TDocument-Test.vala"
		mod = _tmp27_;
#line 42 "SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (mod != NULL, "mod != null");
#line 43 "SerializableObjectModel-TDocument-Test.vala"
		_tmp28_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 43 "SerializableObjectModel-TDocument-Test.vala"
		_tmp29_ = _tmp28_;
#line 43 "SerializableObjectModel-TDocument-Test.vala"
		_tmp30_ = _tmp29_;
#line 43 "SerializableObjectModel-TDocument-Test.vala"
		_tmp31_ = gxml_node_get_attrs (_tmp30_);
#line 43 "SerializableObjectModel-TDocument-Test.vala"
		_tmp32_ = _tmp31_;
#line 43 "SerializableObjectModel-TDocument-Test.vala"
		_tmp33_ = _tmp32_;
#line 43 "SerializableObjectModel-TDocument-Test.vala"
		_tmp34_ = gee_map_get (_tmp33_, "cores");
#line 43 "SerializableObjectModel-TDocument-Test.vala"
		_tmp35_ = (GXmlNode*) _tmp34_;
#line 43 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp33_);
#line 43 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp30_);
#line 43 "SerializableObjectModel-TDocument-Test.vala"
		c = _tmp35_;
#line 44 "SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (c != NULL, "c != null");
#line 45 "SerializableObjectModel-TDocument-Test.vala"
		_tmp36_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 45 "SerializableObjectModel-TDocument-Test.vala"
		_tmp37_ = _tmp36_;
#line 45 "SerializableObjectModel-TDocument-Test.vala"
		_tmp38_ = _tmp37_;
#line 45 "SerializableObjectModel-TDocument-Test.vala"
		_tmp39_ = gxml_node_get_attrs (_tmp38_);
#line 45 "SerializableObjectModel-TDocument-Test.vala"
		_tmp40_ = _tmp39_;
#line 45 "SerializableObjectModel-TDocument-Test.vala"
		_tmp41_ = _tmp40_;
#line 45 "SerializableObjectModel-TDocument-Test.vala"
		_tmp42_ = gee_map_get (_tmp41_, "ghz");
#line 45 "SerializableObjectModel-TDocument-Test.vala"
		_tmp43_ = (GXmlNode*) _tmp42_;
#line 45 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp41_);
#line 45 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp38_);
#line 45 "SerializableObjectModel-TDocument-Test.vala"
		g = _tmp43_;
#line 46 "SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (g != NULL, "g != null");
#line 34 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (g);
#line 34 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (c);
#line 34 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (mod);
#line 34 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (m);
#line 34 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (doc);
#line 34 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (computer);
#line 415 "SerializableObjectModel-TDocument-Test.c"
	}
	goto __finally337;
	__catch337_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp44_;
#line 34 "SerializableObjectModel-TDocument-Test.vala"
		e = _inner_error0_;
#line 34 "SerializableObjectModel-TDocument-Test.vala"
		_inner_error0_ = NULL;
#line 50 "SerializableObjectModel-TDocument-Test.vala"
		_tmp44_ = e->message;
#line 50 "SerializableObjectModel-TDocument-Test.vala"
		g_message ("SerializableObjectModel-TDocument-Test.vala:50: %s", _tmp44_);
#line 51 "SerializableObjectModel-TDocument-Test.vala"
		g_assert_not_reached ();
#line 34 "SerializableObjectModel-TDocument-Test.vala"
		_g_error_free0 (e);
#line 434 "SerializableObjectModel-TDocument-Test.c"
	}
	__finally337:
#line 34 "SerializableObjectModel-TDocument-Test.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 34 "SerializableObjectModel-TDocument-Test.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 34 "SerializableObjectModel-TDocument-Test.vala"
		g_clear_error (&_inner_error0_);
#line 34 "SerializableObjectModel-TDocument-Test.vala"
		return;
#line 445 "SerializableObjectModel-TDocument-Test.c"
	}
}

static void
___lambda283__gtest_func (void)
{
#line 32 "SerializableObjectModel-TDocument-Test.vala"
	__lambda283_ ();
#line 454 "SerializableObjectModel-TDocument-Test.c"
}

static const gchar*
string_to_string (const gchar* self)
{
	const gchar* result = NULL;
#line 1516 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1517 "glib-2.0.vapi"
	result = self;
#line 1517 "glib-2.0.vapi"
	return result;
#line 467 "SerializableObjectModel-TDocument-Test.c"
}

static void
__lambda284_ (void)
{
	GXmlTDocument* doc = NULL;
	GXmlTDocument* _tmp0_;
	Manual* manual = NULL;
	Manual* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gint _tmp4_;
	gint _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	GError* _inner_error0_ = NULL;
#line 57 "SerializableObjectModel-TDocument-Test.vala"
	_tmp0_ = gxml_tdocument_new ();
#line 57 "SerializableObjectModel-TDocument-Test.vala"
	doc = _tmp0_;
#line 58 "SerializableObjectModel-TDocument-Test.vala"
	_tmp1_ = manual_new ();
#line 58 "SerializableObjectModel-TDocument-Test.vala"
	manual = _tmp1_;
#line 59 "SerializableObjectModel-TDocument-Test.vala"
	_tmp2_ = manual_get_document (manual);
#line 59 "SerializableObjectModel-TDocument-Test.vala"
	_tmp3_ = _tmp2_;
#line 59 "SerializableObjectModel-TDocument-Test.vala"
	_vala_assert (g_strcmp0 (_tmp3_, "MANUAL DOCUMENTATION") == 0, "manual.document == \"MANUAL DOCUMENTATION\"");
#line 60 "SerializableObjectModel-TDocument-Test.vala"
	_tmp4_ = manual_get_pages (manual);
#line 60 "SerializableObjectModel-TDocument-Test.vala"
	_tmp5_ = _tmp4_;
#line 60 "SerializableObjectModel-TDocument-Test.vala"
	_vala_assert (_tmp5_ == 3, "manual.pages == 3");
#line 61 "SerializableObjectModel-TDocument-Test.vala"
	_tmp6_ = manual_get_contents (manual);
#line 61 "SerializableObjectModel-TDocument-Test.vala"
	_tmp7_ = _tmp6_;
#line 61 "SerializableObjectModel-TDocument-Test.vala"
	_vala_assert (g_strcmp0 (_tmp7_, "TEXT INTO THE MANUAL DOCUMENT") == 0, "manual.get_contents () == \"TEXT INTO THE MANUAL DOCUMENT\"");
#line 61 "SerializableObjectModel-TDocument-Test.vala"
	_g_free0 (_tmp7_);
#line 512 "SerializableObjectModel-TDocument-Test.c"
	{
		GXmlNode* _tmp8_;
		GXmlNode* _tmp9_;
#line 63 "SerializableObjectModel-TDocument-Test.vala"
		_tmp8_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) manual, (GXmlNode*) doc, &_inner_error0_);
#line 63 "SerializableObjectModel-TDocument-Test.vala"
		_tmp9_ = _tmp8_;
#line 63 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp9_);
#line 63 "SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 524 "SerializableObjectModel-TDocument-Test.c"
			goto __catch338_g_error;
		}
	}
	goto __finally338;
	__catch338_g_error:
	{
		GError* e = NULL;
		FILE* _tmp10_;
		const gchar* _tmp11_;
		const gchar* _tmp12_;
#line 62 "SerializableObjectModel-TDocument-Test.vala"
		e = _inner_error0_;
#line 62 "SerializableObjectModel-TDocument-Test.vala"
		_inner_error0_ = NULL;
#line 66 "SerializableObjectModel-TDocument-Test.vala"
		_tmp10_ = stdout;
#line 66 "SerializableObjectModel-TDocument-Test.vala"
		_tmp11_ = e->message;
#line 66 "SerializableObjectModel-TDocument-Test.vala"
		_tmp12_ = string_to_string (_tmp11_);
#line 66 "SerializableObjectModel-TDocument-Test.vala"
		fprintf (_tmp10_, "%s", _tmp12_);
#line 67 "SerializableObjectModel-TDocument-Test.vala"
		g_assert_not_reached ();
#line 62 "SerializableObjectModel-TDocument-Test.vala"
		_g_error_free0 (e);
#line 551 "SerializableObjectModel-TDocument-Test.c"
	}
	__finally338:
#line 62 "SerializableObjectModel-TDocument-Test.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 62 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (manual);
#line 62 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (doc);
#line 62 "SerializableObjectModel-TDocument-Test.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 62 "SerializableObjectModel-TDocument-Test.vala"
		g_clear_error (&_inner_error0_);
#line 62 "SerializableObjectModel-TDocument-Test.vala"
		return;
#line 566 "SerializableObjectModel-TDocument-Test.c"
	}
#line 56 "SerializableObjectModel-TDocument-Test.vala"
	_g_object_unref0 (manual);
#line 56 "SerializableObjectModel-TDocument-Test.vala"
	_g_object_unref0 (doc);
#line 572 "SerializableObjectModel-TDocument-Test.c"
}

static void
___lambda284__gtest_func (void)
{
#line 55 "SerializableObjectModel-TDocument-Test.vala"
	__lambda284_ ();
#line 580 "SerializableObjectModel-TDocument-Test.c"
}

static void
__lambda285_ (void)
{
	GXmlTDocument* doc = NULL;
	GXmlTDocument* _tmp0_;
	Package* package = NULL;
	Package* _tmp1_;
	GError* _inner_error0_ = NULL;
#line 73 "SerializableObjectModel-TDocument-Test.vala"
	_tmp0_ = gxml_tdocument_new ();
#line 73 "SerializableObjectModel-TDocument-Test.vala"
	doc = _tmp0_;
#line 74 "SerializableObjectModel-TDocument-Test.vala"
	_tmp1_ = package_new ();
#line 74 "SerializableObjectModel-TDocument-Test.vala"
	package = _tmp1_;
#line 599 "SerializableObjectModel-TDocument-Test.c"
	{
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		gboolean _tmp10_;
		GXmlElement* element = NULL;
		GXmlNode* _tmp21_;
		GXmlNode* _tmp22_;
		GXmlNode* source = NULL;
		GeeMap* _tmp23_;
		GeeMap* _tmp24_;
		GeeMap* _tmp25_;
		gpointer _tmp26_;
		GXmlNode* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		gchar* _tmp30_;
		gboolean _tmp31_;
		GXmlNode* destiny = NULL;
		GeeMap* _tmp39_;
		GeeMap* _tmp40_;
		GeeMap* _tmp41_;
		gpointer _tmp42_;
		GXmlNode* _tmp43_;
		gchar* _tmp44_;
		gchar* _tmp45_;
		gchar* _tmp46_;
		gboolean _tmp47_;
#line 76 "SerializableObjectModel-TDocument-Test.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) package, (GXmlNode*) doc, &_inner_error0_);
#line 76 "SerializableObjectModel-TDocument-Test.vala"
		_tmp3_ = _tmp2_;
#line 76 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp3_);
#line 76 "SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 641 "SerializableObjectModel-TDocument-Test.c"
			goto __catch339_g_error;
		}
#line 77 "SerializableObjectModel-TDocument-Test.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 77 "SerializableObjectModel-TDocument-Test.vala"
		_tmp5_ = _tmp4_;
#line 77 "SerializableObjectModel-TDocument-Test.vala"
		_tmp6_ = _tmp5_;
#line 77 "SerializableObjectModel-TDocument-Test.vala"
		_tmp7_ = gxml_node_get_name (_tmp6_);
#line 77 "SerializableObjectModel-TDocument-Test.vala"
		_tmp8_ = _tmp7_;
#line 77 "SerializableObjectModel-TDocument-Test.vala"
		_tmp9_ = _tmp8_;
#line 77 "SerializableObjectModel-TDocument-Test.vala"
		_tmp10_ = g_strcmp0 (_tmp9_, "package") != 0;
#line 77 "SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp9_);
#line 77 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp6_);
#line 77 "SerializableObjectModel-TDocument-Test.vala"
		if (_tmp10_) {
#line 664 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp11_;
			GXmlNode* _tmp12_;
			GXmlNode* _tmp13_;
			GXmlNode* _tmp14_;
			gchar* _tmp15_;
			gchar* _tmp16_;
			gchar* _tmp17_;
			const gchar* _tmp18_;
			gchar* _tmp19_;
			gchar* _tmp20_;
#line 78 "SerializableObjectModel-TDocument-Test.vala"
			_tmp11_ = stdout;
#line 78 "SerializableObjectModel-TDocument-Test.vala"
			_tmp12_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 78 "SerializableObjectModel-TDocument-Test.vala"
			_tmp13_ = _tmp12_;
#line 78 "SerializableObjectModel-TDocument-Test.vala"
			_tmp14_ = _tmp13_;
#line 78 "SerializableObjectModel-TDocument-Test.vala"
			_tmp15_ = gxml_node_get_name (_tmp14_);
#line 78 "SerializableObjectModel-TDocument-Test.vala"
			_tmp16_ = _tmp15_;
#line 78 "SerializableObjectModel-TDocument-Test.vala"
			_tmp17_ = _tmp16_;
#line 78 "SerializableObjectModel-TDocument-Test.vala"
			_tmp18_ = string_to_string (_tmp17_);
#line 78 "SerializableObjectModel-TDocument-Test.vala"
			_tmp19_ = g_strconcat ("ERROR MANUAL:  GElement: ", _tmp18_, "\n", NULL);
#line 78 "SerializableObjectModel-TDocument-Test.vala"
			_tmp20_ = _tmp19_;
#line 78 "SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp11_, "%s", _tmp20_);
#line 78 "SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp20_);
#line 78 "SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp17_);
#line 78 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (_tmp14_);
#line 79 "SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 705 "SerializableObjectModel-TDocument-Test.c"
		}
#line 81 "SerializableObjectModel-TDocument-Test.vala"
		_tmp21_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 81 "SerializableObjectModel-TDocument-Test.vala"
		_tmp22_ = _tmp21_;
#line 81 "SerializableObjectModel-TDocument-Test.vala"
		element = G_TYPE_CHECK_INSTANCE_CAST (_tmp22_, GXML_TYPE_ELEMENT, GXmlElement);
#line 82 "SerializableObjectModel-TDocument-Test.vala"
		_tmp23_ = gxml_node_get_attrs ((GXmlNode*) element);
#line 82 "SerializableObjectModel-TDocument-Test.vala"
		_tmp24_ = _tmp23_;
#line 82 "SerializableObjectModel-TDocument-Test.vala"
		_tmp25_ = _tmp24_;
#line 82 "SerializableObjectModel-TDocument-Test.vala"
		_tmp26_ = gee_map_get (_tmp25_, "source");
#line 82 "SerializableObjectModel-TDocument-Test.vala"
		_tmp27_ = (GXmlNode*) _tmp26_;
#line 82 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp25_);
#line 82 "SerializableObjectModel-TDocument-Test.vala"
		source = _tmp27_;
#line 83 "SerializableObjectModel-TDocument-Test.vala"
		if (source == NULL) {
#line 83 "SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 731 "SerializableObjectModel-TDocument-Test.c"
		}
#line 84 "SerializableObjectModel-TDocument-Test.vala"
		_tmp28_ = gxml_node_get_value (source);
#line 84 "SerializableObjectModel-TDocument-Test.vala"
		_tmp29_ = _tmp28_;
#line 84 "SerializableObjectModel-TDocument-Test.vala"
		_tmp30_ = _tmp29_;
#line 84 "SerializableObjectModel-TDocument-Test.vala"
		_tmp31_ = g_strcmp0 (_tmp30_, "Mexico") != 0;
#line 84 "SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp30_);
#line 84 "SerializableObjectModel-TDocument-Test.vala"
		if (_tmp31_) {
#line 745 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp32_;
			gchar* _tmp33_;
			gchar* _tmp34_;
			gchar* _tmp35_;
			const gchar* _tmp36_;
			gchar* _tmp37_;
			gchar* _tmp38_;
#line 85 "SerializableObjectModel-TDocument-Test.vala"
			_tmp32_ = stdout;
#line 85 "SerializableObjectModel-TDocument-Test.vala"
			_tmp33_ = gxml_node_get_value (source);
#line 85 "SerializableObjectModel-TDocument-Test.vala"
			_tmp34_ = _tmp33_;
#line 85 "SerializableObjectModel-TDocument-Test.vala"
			_tmp35_ = _tmp34_;
#line 85 "SerializableObjectModel-TDocument-Test.vala"
			_tmp36_ = string_to_string (_tmp35_);
#line 85 "SerializableObjectModel-TDocument-Test.vala"
			_tmp37_ = g_strconcat ("ERROR PACKAGE: source: ", _tmp36_, "\n", NULL);
#line 85 "SerializableObjectModel-TDocument-Test.vala"
			_tmp38_ = _tmp37_;
#line 85 "SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp32_, "%s", _tmp38_);
#line 85 "SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp38_);
#line 85 "SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp35_);
#line 86 "SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 775 "SerializableObjectModel-TDocument-Test.c"
		}
#line 88 "SerializableObjectModel-TDocument-Test.vala"
		_tmp39_ = gxml_node_get_attrs ((GXmlNode*) element);
#line 88 "SerializableObjectModel-TDocument-Test.vala"
		_tmp40_ = _tmp39_;
#line 88 "SerializableObjectModel-TDocument-Test.vala"
		_tmp41_ = _tmp40_;
#line 88 "SerializableObjectModel-TDocument-Test.vala"
		_tmp42_ = gee_map_get (_tmp41_, "destiny");
#line 88 "SerializableObjectModel-TDocument-Test.vala"
		_tmp43_ = (GXmlNode*) _tmp42_;
#line 88 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp41_);
#line 88 "SerializableObjectModel-TDocument-Test.vala"
		destiny = _tmp43_;
#line 89 "SerializableObjectModel-TDocument-Test.vala"
		if (destiny == NULL) {
#line 89 "SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 795 "SerializableObjectModel-TDocument-Test.c"
		}
#line 90 "SerializableObjectModel-TDocument-Test.vala"
		_tmp44_ = gxml_node_get_value (destiny);
#line 90 "SerializableObjectModel-TDocument-Test.vala"
		_tmp45_ = _tmp44_;
#line 90 "SerializableObjectModel-TDocument-Test.vala"
		_tmp46_ = _tmp45_;
#line 90 "SerializableObjectModel-TDocument-Test.vala"
		_tmp47_ = g_strcmp0 (_tmp46_, "World") != 0;
#line 90 "SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp46_);
#line 90 "SerializableObjectModel-TDocument-Test.vala"
		if (_tmp47_) {
#line 809 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp48_;
			gchar* _tmp49_;
			gchar* _tmp50_;
			gchar* _tmp51_;
			const gchar* _tmp52_;
			gchar* _tmp53_;
			gchar* _tmp54_;
#line 91 "SerializableObjectModel-TDocument-Test.vala"
			_tmp48_ = stdout;
#line 91 "SerializableObjectModel-TDocument-Test.vala"
			_tmp49_ = gxml_node_get_value (destiny);
#line 91 "SerializableObjectModel-TDocument-Test.vala"
			_tmp50_ = _tmp49_;
#line 91 "SerializableObjectModel-TDocument-Test.vala"
			_tmp51_ = _tmp50_;
#line 91 "SerializableObjectModel-TDocument-Test.vala"
			_tmp52_ = string_to_string (_tmp51_);
#line 91 "SerializableObjectModel-TDocument-Test.vala"
			_tmp53_ = g_strconcat ("ERROR PACKAGE: source: ", _tmp52_, "\n", NULL);
#line 91 "SerializableObjectModel-TDocument-Test.vala"
			_tmp54_ = _tmp53_;
#line 91 "SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp48_, "%s", _tmp54_);
#line 91 "SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp54_);
#line 91 "SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp51_);
#line 92 "SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 839 "SerializableObjectModel-TDocument-Test.c"
		}
#line 75 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (destiny);
#line 75 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (source);
#line 75 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (element);
#line 847 "SerializableObjectModel-TDocument-Test.c"
	}
	goto __finally339;
	__catch339_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp55_;
		const gchar* _tmp56_;
		gchar* _tmp57_;
		gchar* _tmp58_;
#line 75 "SerializableObjectModel-TDocument-Test.vala"
		e = _inner_error0_;
#line 75 "SerializableObjectModel-TDocument-Test.vala"
		_inner_error0_ = NULL;
#line 96 "SerializableObjectModel-TDocument-Test.vala"
		_tmp55_ = e->message;
#line 96 "SerializableObjectModel-TDocument-Test.vala"
		_tmp56_ = string_to_string (_tmp55_);
#line 96 "SerializableObjectModel-TDocument-Test.vala"
		_tmp57_ = g_strconcat ("Error: ", _tmp56_, NULL);
#line 96 "SerializableObjectModel-TDocument-Test.vala"
		_tmp58_ = _tmp57_;
#line 96 "SerializableObjectModel-TDocument-Test.vala"
		g_message ("SerializableObjectModel-TDocument-Test.vala:96: %s", _tmp58_);
#line 96 "SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp58_);
#line 97 "SerializableObjectModel-TDocument-Test.vala"
		g_assert_not_reached ();
#line 75 "SerializableObjectModel-TDocument-Test.vala"
		_g_error_free0 (e);
#line 877 "SerializableObjectModel-TDocument-Test.c"
	}
	__finally339:
#line 75 "SerializableObjectModel-TDocument-Test.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 75 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (package);
#line 75 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (doc);
#line 75 "SerializableObjectModel-TDocument-Test.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 75 "SerializableObjectModel-TDocument-Test.vala"
		g_clear_error (&_inner_error0_);
#line 75 "SerializableObjectModel-TDocument-Test.vala"
		return;
#line 892 "SerializableObjectModel-TDocument-Test.c"
	}
#line 72 "SerializableObjectModel-TDocument-Test.vala"
	_g_object_unref0 (package);
#line 72 "SerializableObjectModel-TDocument-Test.vala"
	_g_object_unref0 (doc);
#line 898 "SerializableObjectModel-TDocument-Test.c"
}

static void
___lambda285__gtest_func (void)
{
#line 71 "SerializableObjectModel-TDocument-Test.vala"
	__lambda285_ ();
#line 906 "SerializableObjectModel-TDocument-Test.c"
}

static void
__lambda286_ (void)
{
	GXmlTDocument* doc = NULL;
	GXmlTDocument* _tmp0_;
	Package* package = NULL;
	Package* _tmp1_;
	GArray* _tmp2_;
	GArray* _tmp3_;
	gchar* _tmp4_;
	GArray* _tmp5_;
	GArray* _tmp6_;
	gchar* _tmp7_;
	GArray* _tmp8_;
	GArray* _tmp9_;
	gchar* _tmp10_;
	GError* _inner_error0_ = NULL;
#line 102 "SerializableObjectModel-TDocument-Test.vala"
	_tmp0_ = gxml_tdocument_new ();
#line 102 "SerializableObjectModel-TDocument-Test.vala"
	doc = _tmp0_;
#line 103 "SerializableObjectModel-TDocument-Test.vala"
	_tmp1_ = package_new ();
#line 103 "SerializableObjectModel-TDocument-Test.vala"
	package = _tmp1_;
#line 104 "SerializableObjectModel-TDocument-Test.vala"
	_tmp2_ = package_get_tags (package);
#line 104 "SerializableObjectModel-TDocument-Test.vala"
	_tmp3_ = _tmp2_;
#line 104 "SerializableObjectModel-TDocument-Test.vala"
	_tmp4_ = g_strdup ("Computer");
#line 104 "SerializableObjectModel-TDocument-Test.vala"
	g_array_append_val (_tmp3_, _tmp4_);
#line 105 "SerializableObjectModel-TDocument-Test.vala"
	_tmp5_ = package_get_tags (package);
#line 105 "SerializableObjectModel-TDocument-Test.vala"
	_tmp6_ = _tmp5_;
#line 105 "SerializableObjectModel-TDocument-Test.vala"
	_tmp7_ = g_strdup ("Customer");
#line 105 "SerializableObjectModel-TDocument-Test.vala"
	g_array_append_val (_tmp6_, _tmp7_);
#line 106 "SerializableObjectModel-TDocument-Test.vala"
	_tmp8_ = package_get_tags (package);
#line 106 "SerializableObjectModel-TDocument-Test.vala"
	_tmp9_ = _tmp8_;
#line 106 "SerializableObjectModel-TDocument-Test.vala"
	_tmp10_ = g_strdup ("Sale");
#line 106 "SerializableObjectModel-TDocument-Test.vala"
	g_array_append_val (_tmp9_, _tmp10_);
#line 958 "SerializableObjectModel-TDocument-Test.c"
	{
		GXmlNode* _tmp11_;
		GXmlNode* _tmp12_;
		GXmlNode* _tmp13_;
		GXmlNode* _tmp14_;
		GXmlNode* _tmp15_;
		gchar* _tmp16_;
		gchar* _tmp17_;
		gchar* _tmp18_;
		gboolean _tmp19_;
		GXmlElement* element = NULL;
		GXmlNode* _tmp20_;
		GXmlNode* _tmp21_;
		gboolean com = FALSE;
		gboolean cus = FALSE;
		gboolean sal = FALSE;
#line 108 "SerializableObjectModel-TDocument-Test.vala"
		_tmp11_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) package, (GXmlNode*) doc, &_inner_error0_);
#line 108 "SerializableObjectModel-TDocument-Test.vala"
		_tmp12_ = _tmp11_;
#line 108 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp12_);
#line 108 "SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 983 "SerializableObjectModel-TDocument-Test.c"
			goto __catch340_g_error;
		}
#line 110 "SerializableObjectModel-TDocument-Test.vala"
		_tmp13_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 110 "SerializableObjectModel-TDocument-Test.vala"
		_tmp14_ = _tmp13_;
#line 110 "SerializableObjectModel-TDocument-Test.vala"
		_tmp15_ = _tmp14_;
#line 110 "SerializableObjectModel-TDocument-Test.vala"
		_tmp16_ = gxml_node_get_name (_tmp15_);
#line 110 "SerializableObjectModel-TDocument-Test.vala"
		_tmp17_ = _tmp16_;
#line 110 "SerializableObjectModel-TDocument-Test.vala"
		_tmp18_ = _tmp17_;
#line 110 "SerializableObjectModel-TDocument-Test.vala"
		_tmp19_ = g_strcmp0 (_tmp18_, "package") != 0;
#line 110 "SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp18_);
#line 110 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp15_);
#line 110 "SerializableObjectModel-TDocument-Test.vala"
		if (_tmp19_) {
#line 111 "SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1008 "SerializableObjectModel-TDocument-Test.c"
		}
#line 112 "SerializableObjectModel-TDocument-Test.vala"
		_tmp20_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 112 "SerializableObjectModel-TDocument-Test.vala"
		_tmp21_ = _tmp20_;
#line 112 "SerializableObjectModel-TDocument-Test.vala"
		element = G_TYPE_CHECK_INSTANCE_CAST (_tmp21_, GXML_TYPE_ELEMENT, GXmlElement);
#line 113 "SerializableObjectModel-TDocument-Test.vala"
		com = FALSE;
#line 114 "SerializableObjectModel-TDocument-Test.vala"
		cus = FALSE;
#line 115 "SerializableObjectModel-TDocument-Test.vala"
		sal = FALSE;
#line 1022 "SerializableObjectModel-TDocument-Test.c"
		{
			GeeBidirList* _n_list = NULL;
			GXmlElement* _tmp22_;
			GeeBidirList* _tmp23_;
			GeeBidirList* _tmp24_;
			gint _n_size = 0;
			GeeBidirList* _tmp25_;
			gint _tmp26_;
			gint _tmp27_;
			gint _n_index = 0;
#line 116 "SerializableObjectModel-TDocument-Test.vala"
			_tmp22_ = element;
#line 116 "SerializableObjectModel-TDocument-Test.vala"
			_tmp23_ = gxml_node_get_children_nodes ((GXmlNode*) _tmp22_);
#line 116 "SerializableObjectModel-TDocument-Test.vala"
			_tmp24_ = _tmp23_;
#line 116 "SerializableObjectModel-TDocument-Test.vala"
			_n_list = _tmp24_;
#line 116 "SerializableObjectModel-TDocument-Test.vala"
			_tmp25_ = _n_list;
#line 116 "SerializableObjectModel-TDocument-Test.vala"
			_tmp26_ = gee_collection_get_size ((GeeCollection*) _tmp25_);
#line 116 "SerializableObjectModel-TDocument-Test.vala"
			_tmp27_ = _tmp26_;
#line 116 "SerializableObjectModel-TDocument-Test.vala"
			_n_size = _tmp27_;
#line 116 "SerializableObjectModel-TDocument-Test.vala"
			_n_index = -1;
#line 116 "SerializableObjectModel-TDocument-Test.vala"
			while (TRUE) {
#line 1053 "SerializableObjectModel-TDocument-Test.c"
				GXmlNode* n = NULL;
				GeeBidirList* _tmp28_;
				gpointer _tmp29_;
				GXmlNode* _tmp30_;
				gchar* _tmp31_;
				gchar* _tmp32_;
				gchar* _tmp33_;
				gboolean _tmp34_;
#line 116 "SerializableObjectModel-TDocument-Test.vala"
				_n_index = _n_index + 1;
#line 116 "SerializableObjectModel-TDocument-Test.vala"
				if (!(_n_index < _n_size)) {
#line 116 "SerializableObjectModel-TDocument-Test.vala"
					break;
#line 1068 "SerializableObjectModel-TDocument-Test.c"
				}
#line 116 "SerializableObjectModel-TDocument-Test.vala"
				_tmp28_ = _n_list;
#line 116 "SerializableObjectModel-TDocument-Test.vala"
				_tmp29_ = gee_list_get ((GeeList*) _tmp28_, _n_index);
#line 116 "SerializableObjectModel-TDocument-Test.vala"
				n = (GXmlNode*) _tmp29_;
#line 118 "SerializableObjectModel-TDocument-Test.vala"
				_tmp30_ = n;
#line 118 "SerializableObjectModel-TDocument-Test.vala"
				_tmp31_ = gxml_node_get_name (_tmp30_);
#line 118 "SerializableObjectModel-TDocument-Test.vala"
				_tmp32_ = _tmp31_;
#line 118 "SerializableObjectModel-TDocument-Test.vala"
				_tmp33_ = _tmp32_;
#line 118 "SerializableObjectModel-TDocument-Test.vala"
				_tmp34_ = g_strcmp0 (_tmp33_, "tag") == 0;
#line 118 "SerializableObjectModel-TDocument-Test.vala"
				_g_free0 (_tmp33_);
#line 118 "SerializableObjectModel-TDocument-Test.vala"
				if (_tmp34_) {
#line 1090 "SerializableObjectModel-TDocument-Test.c"
					GXmlNode* _tmp35_;
					gchar* _tmp36_;
					gchar* _tmp37_;
					gchar* _tmp38_;
					gboolean _tmp39_;
					GXmlNode* _tmp40_;
					gchar* _tmp41_;
					gchar* _tmp42_;
					gchar* _tmp43_;
					gboolean _tmp44_;
					GXmlNode* _tmp45_;
					gchar* _tmp46_;
					gchar* _tmp47_;
					gchar* _tmp48_;
					gboolean _tmp49_;
#line 120 "SerializableObjectModel-TDocument-Test.vala"
					_tmp35_ = n;
#line 120 "SerializableObjectModel-TDocument-Test.vala"
					_tmp36_ = gxml_element_get_content (G_TYPE_CHECK_INSTANCE_CAST (_tmp35_, GXML_TYPE_ELEMENT, GXmlElement));
#line 120 "SerializableObjectModel-TDocument-Test.vala"
					_tmp37_ = _tmp36_;
#line 120 "SerializableObjectModel-TDocument-Test.vala"
					_tmp38_ = _tmp37_;
#line 120 "SerializableObjectModel-TDocument-Test.vala"
					_tmp39_ = g_strcmp0 (_tmp38_, "Computer") == 0;
#line 120 "SerializableObjectModel-TDocument-Test.vala"
					_g_free0 (_tmp38_);
#line 120 "SerializableObjectModel-TDocument-Test.vala"
					if (_tmp39_) {
#line 121 "SerializableObjectModel-TDocument-Test.vala"
						com = TRUE;
#line 1122 "SerializableObjectModel-TDocument-Test.c"
					}
#line 122 "SerializableObjectModel-TDocument-Test.vala"
					_tmp40_ = n;
#line 122 "SerializableObjectModel-TDocument-Test.vala"
					_tmp41_ = gxml_element_get_content (G_TYPE_CHECK_INSTANCE_CAST (_tmp40_, GXML_TYPE_ELEMENT, GXmlElement));
#line 122 "SerializableObjectModel-TDocument-Test.vala"
					_tmp42_ = _tmp41_;
#line 122 "SerializableObjectModel-TDocument-Test.vala"
					_tmp43_ = _tmp42_;
#line 122 "SerializableObjectModel-TDocument-Test.vala"
					_tmp44_ = g_strcmp0 (_tmp43_, "Customer") == 0;
#line 122 "SerializableObjectModel-TDocument-Test.vala"
					_g_free0 (_tmp43_);
#line 122 "SerializableObjectModel-TDocument-Test.vala"
					if (_tmp44_) {
#line 123 "SerializableObjectModel-TDocument-Test.vala"
						cus = TRUE;
#line 1140 "SerializableObjectModel-TDocument-Test.c"
					}
#line 124 "SerializableObjectModel-TDocument-Test.vala"
					_tmp45_ = n;
#line 124 "SerializableObjectModel-TDocument-Test.vala"
					_tmp46_ = gxml_element_get_content (G_TYPE_CHECK_INSTANCE_CAST (_tmp45_, GXML_TYPE_ELEMENT, GXmlElement));
#line 124 "SerializableObjectModel-TDocument-Test.vala"
					_tmp47_ = _tmp46_;
#line 124 "SerializableObjectModel-TDocument-Test.vala"
					_tmp48_ = _tmp47_;
#line 124 "SerializableObjectModel-TDocument-Test.vala"
					_tmp49_ = g_strcmp0 (_tmp48_, "Sale") == 0;
#line 124 "SerializableObjectModel-TDocument-Test.vala"
					_g_free0 (_tmp48_);
#line 124 "SerializableObjectModel-TDocument-Test.vala"
					if (_tmp49_) {
#line 125 "SerializableObjectModel-TDocument-Test.vala"
						sal = TRUE;
#line 1158 "SerializableObjectModel-TDocument-Test.c"
					}
				}
#line 116 "SerializableObjectModel-TDocument-Test.vala"
				_g_object_unref0 (n);
#line 1163 "SerializableObjectModel-TDocument-Test.c"
			}
#line 116 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (_n_list);
#line 1167 "SerializableObjectModel-TDocument-Test.c"
		}
#line 128 "SerializableObjectModel-TDocument-Test.vala"
		if (!com) {
#line 1171 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp50_;
#line 129 "SerializableObjectModel-TDocument-Test.vala"
			_tmp50_ = stdout;
#line 129 "SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp50_, "%s", "ERROR PACKAGE tag Computer not found!");
#line 130 "SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1179 "SerializableObjectModel-TDocument-Test.c"
		}
#line 132 "SerializableObjectModel-TDocument-Test.vala"
		if (!cus) {
#line 1183 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp51_;
#line 133 "SerializableObjectModel-TDocument-Test.vala"
			_tmp51_ = stdout;
#line 133 "SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp51_, "%s", "ERROR PACKAGE tag Customer not found!");
#line 134 "SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1191 "SerializableObjectModel-TDocument-Test.c"
		}
#line 136 "SerializableObjectModel-TDocument-Test.vala"
		if (!sal) {
#line 1195 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp52_;
#line 137 "SerializableObjectModel-TDocument-Test.vala"
			_tmp52_ = stdout;
#line 137 "SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp52_, "%s", "ERROR PACKAGE tag Sale not found!");
#line 138 "SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1203 "SerializableObjectModel-TDocument-Test.c"
		}
#line 107 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (element);
#line 1207 "SerializableObjectModel-TDocument-Test.c"
	}
	goto __finally340;
	__catch340_g_error:
	{
		GError* e = NULL;
		const gchar* _tmp53_;
		const gchar* _tmp54_;
		gchar* _tmp55_;
		gchar* _tmp56_;
#line 107 "SerializableObjectModel-TDocument-Test.vala"
		e = _inner_error0_;
#line 107 "SerializableObjectModel-TDocument-Test.vala"
		_inner_error0_ = NULL;
#line 142 "SerializableObjectModel-TDocument-Test.vala"
		_tmp53_ = e->message;
#line 142 "SerializableObjectModel-TDocument-Test.vala"
		_tmp54_ = string_to_string (_tmp53_);
#line 142 "SerializableObjectModel-TDocument-Test.vala"
		_tmp55_ = g_strconcat ("Error: ", _tmp54_, NULL);
#line 142 "SerializableObjectModel-TDocument-Test.vala"
		_tmp56_ = _tmp55_;
#line 142 "SerializableObjectModel-TDocument-Test.vala"
		g_message ("SerializableObjectModel-TDocument-Test.vala:142: %s", _tmp56_);
#line 142 "SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp56_);
#line 143 "SerializableObjectModel-TDocument-Test.vala"
		g_assert_not_reached ();
#line 107 "SerializableObjectModel-TDocument-Test.vala"
		_g_error_free0 (e);
#line 1237 "SerializableObjectModel-TDocument-Test.c"
	}
	__finally340:
#line 107 "SerializableObjectModel-TDocument-Test.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 107 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (package);
#line 107 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (doc);
#line 107 "SerializableObjectModel-TDocument-Test.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 107 "SerializableObjectModel-TDocument-Test.vala"
		g_clear_error (&_inner_error0_);
#line 107 "SerializableObjectModel-TDocument-Test.vala"
		return;
#line 1252 "SerializableObjectModel-TDocument-Test.c"
	}
#line 101 "SerializableObjectModel-TDocument-Test.vala"
	_g_object_unref0 (package);
#line 101 "SerializableObjectModel-TDocument-Test.vala"
	_g_object_unref0 (doc);
#line 1258 "SerializableObjectModel-TDocument-Test.c"
}

static void
___lambda286__gtest_func (void)
{
#line 100 "SerializableObjectModel-TDocument-Test.vala"
	__lambda286_ ();
#line 1266 "SerializableObjectModel-TDocument-Test.c"
}

static void
__lambda287_ (void)
{
	GXmlTDocument* doc = NULL;
	GXmlTDocument* _tmp0_;
	Monitor* monitor = NULL;
	Monitor* _tmp1_;
	GError* _inner_error0_ = NULL;
#line 148 "SerializableObjectModel-TDocument-Test.vala"
	_tmp0_ = gxml_tdocument_new ();
#line 148 "SerializableObjectModel-TDocument-Test.vala"
	doc = _tmp0_;
#line 149 "SerializableObjectModel-TDocument-Test.vala"
	_tmp1_ = monitor_new ();
#line 149 "SerializableObjectModel-TDocument-Test.vala"
	monitor = _tmp1_;
#line 1285 "SerializableObjectModel-TDocument-Test.c"
	{
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		gboolean _tmp7_;
		GXmlElement* element = NULL;
		GXmlNode* _tmp9_;
		GXmlNode* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gchar* _tmp13_;
		gboolean _tmp14_;
		GXmlNode* ac = NULL;
		GeeMap* _tmp22_;
		GeeMap* _tmp23_;
		GeeMap* _tmp24_;
		gpointer _tmp25_;
		GXmlNode* _tmp26_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		gchar* _tmp30_;
		gboolean _tmp31_;
		GXmlNode* dc = NULL;
		GeeMap* _tmp39_;
		GeeMap* _tmp40_;
		GeeMap* _tmp41_;
		gpointer _tmp42_;
		GXmlNode* _tmp43_;
		gchar* _tmp45_;
		gchar* _tmp46_;
		gchar* _tmp47_;
		gboolean _tmp48_;
		GXmlNode* r = NULL;
		GeeMap* _tmp56_;
		GeeMap* _tmp57_;
		GeeMap* _tmp58_;
		gpointer _tmp59_;
		GXmlNode* _tmp60_;
		gchar* _tmp62_;
		gchar* _tmp63_;
		gchar* _tmp64_;
		gboolean _tmp65_;
#line 151 "SerializableObjectModel-TDocument-Test.vala"
		monitor_set_resolution (monitor, "1204x720");
#line 152 "SerializableObjectModel-TDocument-Test.vala"
		monitor_set_ac_power (monitor, 120);
#line 153 "SerializableObjectModel-TDocument-Test.vala"
		monitor_set_dc_power (monitor, 125);
#line 154 "SerializableObjectModel-TDocument-Test.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) monitor, (GXmlNode*) doc, &_inner_error0_);
#line 154 "SerializableObjectModel-TDocument-Test.vala"
		_tmp3_ = _tmp2_;
#line 154 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp3_);
#line 154 "SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1344 "SerializableObjectModel-TDocument-Test.c"
			goto __catch341_g_error;
		}
#line 156 "SerializableObjectModel-TDocument-Test.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 156 "SerializableObjectModel-TDocument-Test.vala"
		_tmp5_ = _tmp4_;
#line 156 "SerializableObjectModel-TDocument-Test.vala"
		_tmp6_ = _tmp5_;
#line 156 "SerializableObjectModel-TDocument-Test.vala"
		_tmp7_ = _tmp6_ == NULL;
#line 156 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp6_);
#line 156 "SerializableObjectModel-TDocument-Test.vala"
		if (_tmp7_) {
#line 1359 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp8_;
#line 157 "SerializableObjectModel-TDocument-Test.vala"
			_tmp8_ = stdout;
#line 157 "SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp8_, "ERROR MONITOR: No root Element");
#line 158 "SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1367 "SerializableObjectModel-TDocument-Test.c"
		}
#line 160 "SerializableObjectModel-TDocument-Test.vala"
		_tmp9_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 160 "SerializableObjectModel-TDocument-Test.vala"
		_tmp10_ = _tmp9_;
#line 160 "SerializableObjectModel-TDocument-Test.vala"
		element = G_TYPE_CHECK_INSTANCE_CAST (_tmp10_, GXML_TYPE_ELEMENT, GXmlElement);
#line 161 "SerializableObjectModel-TDocument-Test.vala"
		_tmp11_ = gxml_node_get_name ((GXmlNode*) element);
#line 161 "SerializableObjectModel-TDocument-Test.vala"
		_tmp12_ = _tmp11_;
#line 161 "SerializableObjectModel-TDocument-Test.vala"
		_tmp13_ = _tmp12_;
#line 161 "SerializableObjectModel-TDocument-Test.vala"
		_tmp14_ = g_strcmp0 (_tmp13_, "monitor") != 0;
#line 161 "SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp13_);
#line 161 "SerializableObjectModel-TDocument-Test.vala"
		if (_tmp14_) {
#line 1387 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp15_;
			gchar* _tmp16_;
			gchar* _tmp17_;
			gchar* _tmp18_;
			const gchar* _tmp19_;
			gchar* _tmp20_;
			gchar* _tmp21_;
#line 162 "SerializableObjectModel-TDocument-Test.vala"
			_tmp15_ = stdout;
#line 162 "SerializableObjectModel-TDocument-Test.vala"
			_tmp16_ = gxml_node_get_name ((GXmlNode*) element);
#line 162 "SerializableObjectModel-TDocument-Test.vala"
			_tmp17_ = _tmp16_;
#line 162 "SerializableObjectModel-TDocument-Test.vala"
			_tmp18_ = _tmp17_;
#line 162 "SerializableObjectModel-TDocument-Test.vala"
			_tmp19_ = string_to_string (_tmp18_);
#line 162 "SerializableObjectModel-TDocument-Test.vala"
			_tmp20_ = g_strconcat ("ERROR MONITOR: root GElement ", _tmp19_, NULL);
#line 162 "SerializableObjectModel-TDocument-Test.vala"
			_tmp21_ = _tmp20_;
#line 162 "SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp15_, "%s", _tmp21_);
#line 162 "SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp21_);
#line 162 "SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp18_);
#line 163 "SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1417 "SerializableObjectModel-TDocument-Test.c"
		}
#line 165 "SerializableObjectModel-TDocument-Test.vala"
		_tmp22_ = gxml_node_get_attrs ((GXmlNode*) element);
#line 165 "SerializableObjectModel-TDocument-Test.vala"
		_tmp23_ = _tmp22_;
#line 165 "SerializableObjectModel-TDocument-Test.vala"
		_tmp24_ = _tmp23_;
#line 165 "SerializableObjectModel-TDocument-Test.vala"
		_tmp25_ = gee_map_get (_tmp24_, "AcPower");
#line 165 "SerializableObjectModel-TDocument-Test.vala"
		_tmp26_ = (GXmlNode*) _tmp25_;
#line 165 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp24_);
#line 165 "SerializableObjectModel-TDocument-Test.vala"
		ac = _tmp26_;
#line 166 "SerializableObjectModel-TDocument-Test.vala"
		if (ac == NULL) {
#line 1435 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp27_;
#line 167 "SerializableObjectModel-TDocument-Test.vala"
			_tmp27_ = stdout;
#line 167 "SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp27_, "%s", "ERROR MONITOR: attribute AcPower not found");
#line 168 "SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1443 "SerializableObjectModel-TDocument-Test.c"
		}
#line 170 "SerializableObjectModel-TDocument-Test.vala"
		_tmp28_ = gxml_node_get_value (ac);
#line 170 "SerializableObjectModel-TDocument-Test.vala"
		_tmp29_ = _tmp28_;
#line 170 "SerializableObjectModel-TDocument-Test.vala"
		_tmp30_ = _tmp29_;
#line 170 "SerializableObjectModel-TDocument-Test.vala"
		_tmp31_ = g_strcmp0 (_tmp30_, "120") != 0;
#line 170 "SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp30_);
#line 170 "SerializableObjectModel-TDocument-Test.vala"
		if (_tmp31_) {
#line 1457 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp32_;
			gchar* _tmp33_;
			gchar* _tmp34_;
			gchar* _tmp35_;
			const gchar* _tmp36_;
			gchar* _tmp37_;
			gchar* _tmp38_;
#line 171 "SerializableObjectModel-TDocument-Test.vala"
			_tmp32_ = stdout;
#line 171 "SerializableObjectModel-TDocument-Test.vala"
			_tmp33_ = gxml_node_get_value (ac);
#line 171 "SerializableObjectModel-TDocument-Test.vala"
			_tmp34_ = _tmp33_;
#line 171 "SerializableObjectModel-TDocument-Test.vala"
			_tmp35_ = _tmp34_;
#line 171 "SerializableObjectModel-TDocument-Test.vala"
			_tmp36_ = string_to_string (_tmp35_);
#line 171 "SerializableObjectModel-TDocument-Test.vala"
			_tmp37_ = g_strconcat ("ERROR MONITOR: AcPower value ", _tmp36_, NULL);
#line 171 "SerializableObjectModel-TDocument-Test.vala"
			_tmp38_ = _tmp37_;
#line 171 "SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp32_, "%s", _tmp38_);
#line 171 "SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp38_);
#line 171 "SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp35_);
#line 172 "SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1487 "SerializableObjectModel-TDocument-Test.c"
		}
#line 174 "SerializableObjectModel-TDocument-Test.vala"
		_tmp39_ = gxml_node_get_attrs ((GXmlNode*) element);
#line 174 "SerializableObjectModel-TDocument-Test.vala"
		_tmp40_ = _tmp39_;
#line 174 "SerializableObjectModel-TDocument-Test.vala"
		_tmp41_ = _tmp40_;
#line 174 "SerializableObjectModel-TDocument-Test.vala"
		_tmp42_ = gee_map_get (_tmp41_, "DcPower");
#line 174 "SerializableObjectModel-TDocument-Test.vala"
		_tmp43_ = (GXmlNode*) _tmp42_;
#line 174 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp41_);
#line 174 "SerializableObjectModel-TDocument-Test.vala"
		dc = _tmp43_;
#line 175 "SerializableObjectModel-TDocument-Test.vala"
		if (dc == NULL) {
#line 1505 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp44_;
#line 176 "SerializableObjectModel-TDocument-Test.vala"
			_tmp44_ = stdout;
#line 176 "SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp44_, "%s", "ERROR MONITOR: attribute DcPower not found");
#line 177 "SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1513 "SerializableObjectModel-TDocument-Test.c"
		}
#line 179 "SerializableObjectModel-TDocument-Test.vala"
		_tmp45_ = gxml_node_get_value (dc);
#line 179 "SerializableObjectModel-TDocument-Test.vala"
		_tmp46_ = _tmp45_;
#line 179 "SerializableObjectModel-TDocument-Test.vala"
		_tmp47_ = _tmp46_;
#line 179 "SerializableObjectModel-TDocument-Test.vala"
		_tmp48_ = g_strcmp0 (_tmp47_, "125") != 0;
#line 179 "SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp47_);
#line 179 "SerializableObjectModel-TDocument-Test.vala"
		if (_tmp48_) {
#line 1527 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp49_;
			gchar* _tmp50_;
			gchar* _tmp51_;
			gchar* _tmp52_;
			const gchar* _tmp53_;
			gchar* _tmp54_;
			gchar* _tmp55_;
#line 180 "SerializableObjectModel-TDocument-Test.vala"
			_tmp49_ = stdout;
#line 180 "SerializableObjectModel-TDocument-Test.vala"
			_tmp50_ = gxml_node_get_value (dc);
#line 180 "SerializableObjectModel-TDocument-Test.vala"
			_tmp51_ = _tmp50_;
#line 180 "SerializableObjectModel-TDocument-Test.vala"
			_tmp52_ = _tmp51_;
#line 180 "SerializableObjectModel-TDocument-Test.vala"
			_tmp53_ = string_to_string (_tmp52_);
#line 180 "SerializableObjectModel-TDocument-Test.vala"
			_tmp54_ = g_strconcat ("ERROR MONITOR: AcPower value ", _tmp53_, NULL);
#line 180 "SerializableObjectModel-TDocument-Test.vala"
			_tmp55_ = _tmp54_;
#line 180 "SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp49_, "%s", _tmp55_);
#line 180 "SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp55_);
#line 180 "SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp52_);
#line 181 "SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1557 "SerializableObjectModel-TDocument-Test.c"
		}
#line 183 "SerializableObjectModel-TDocument-Test.vala"
		_tmp56_ = gxml_node_get_attrs ((GXmlNode*) element);
#line 183 "SerializableObjectModel-TDocument-Test.vala"
		_tmp57_ = _tmp56_;
#line 183 "SerializableObjectModel-TDocument-Test.vala"
		_tmp58_ = _tmp57_;
#line 183 "SerializableObjectModel-TDocument-Test.vala"
		_tmp59_ = gee_map_get (_tmp58_, "resolution");
#line 183 "SerializableObjectModel-TDocument-Test.vala"
		_tmp60_ = (GXmlNode*) _tmp59_;
#line 183 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp58_);
#line 183 "SerializableObjectModel-TDocument-Test.vala"
		r = _tmp60_;
#line 184 "SerializableObjectModel-TDocument-Test.vala"
		if (r == NULL) {
#line 1575 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp61_;
#line 185 "SerializableObjectModel-TDocument-Test.vala"
			_tmp61_ = stdout;
#line 185 "SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp61_, "%s", "ERROR MONITOR: attribute resolution not found");
#line 186 "SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1583 "SerializableObjectModel-TDocument-Test.c"
		}
#line 188 "SerializableObjectModel-TDocument-Test.vala"
		_tmp62_ = gxml_node_get_value (r);
#line 188 "SerializableObjectModel-TDocument-Test.vala"
		_tmp63_ = _tmp62_;
#line 188 "SerializableObjectModel-TDocument-Test.vala"
		_tmp64_ = _tmp63_;
#line 188 "SerializableObjectModel-TDocument-Test.vala"
		_tmp65_ = g_strcmp0 (_tmp64_, "1204x720") != 0;
#line 188 "SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp64_);
#line 188 "SerializableObjectModel-TDocument-Test.vala"
		if (_tmp65_) {
#line 1597 "SerializableObjectModel-TDocument-Test.c"
			FILE* _tmp66_;
			gchar* _tmp67_;
			gchar* _tmp68_;
			gchar* _tmp69_;
			const gchar* _tmp70_;
			gchar* _tmp71_;
			gchar* _tmp72_;
#line 189 "SerializableObjectModel-TDocument-Test.vala"
			_tmp66_ = stdout;
#line 189 "SerializableObjectModel-TDocument-Test.vala"
			_tmp67_ = gxml_node_get_value (r);
#line 189 "SerializableObjectModel-TDocument-Test.vala"
			_tmp68_ = _tmp67_;
#line 189 "SerializableObjectModel-TDocument-Test.vala"
			_tmp69_ = _tmp68_;
#line 189 "SerializableObjectModel-TDocument-Test.vala"
			_tmp70_ = string_to_string (_tmp69_);
#line 189 "SerializableObjectModel-TDocument-Test.vala"
			_tmp71_ = g_strconcat ("ERROR MONITOR: resolution value ", _tmp70_, NULL);
#line 189 "SerializableObjectModel-TDocument-Test.vala"
			_tmp72_ = _tmp71_;
#line 189 "SerializableObjectModel-TDocument-Test.vala"
			fprintf (_tmp66_, "%s", _tmp72_);
#line 189 "SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp72_);
#line 189 "SerializableObjectModel-TDocument-Test.vala"
			_g_free0 (_tmp69_);
#line 190 "SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1627 "SerializableObjectModel-TDocument-Test.c"
		}
#line 150 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (r);
#line 150 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (dc);
#line 150 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (ac);
#line 150 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (element);
#line 1637 "SerializableObjectModel-TDocument-Test.c"
	}
	goto __finally341;
	__catch341_g_error:
	{
		GError* e = NULL;
		FILE* _tmp73_;
		const gchar* _tmp74_;
		const gchar* _tmp75_;
		gchar* _tmp76_;
		gchar* _tmp77_;
#line 150 "SerializableObjectModel-TDocument-Test.vala"
		e = _inner_error0_;
#line 150 "SerializableObjectModel-TDocument-Test.vala"
		_inner_error0_ = NULL;
#line 194 "SerializableObjectModel-TDocument-Test.vala"
		_tmp73_ = stdout;
#line 194 "SerializableObjectModel-TDocument-Test.vala"
		_tmp74_ = e->message;
#line 194 "SerializableObjectModel-TDocument-Test.vala"
		_tmp75_ = string_to_string (_tmp74_);
#line 194 "SerializableObjectModel-TDocument-Test.vala"
		_tmp76_ = g_strconcat ("Error: ", _tmp75_, NULL);
#line 194 "SerializableObjectModel-TDocument-Test.vala"
		_tmp77_ = _tmp76_;
#line 194 "SerializableObjectModel-TDocument-Test.vala"
		fprintf (_tmp73_, "%s", _tmp77_);
#line 194 "SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp77_);
#line 195 "SerializableObjectModel-TDocument-Test.vala"
		g_assert_not_reached ();
#line 150 "SerializableObjectModel-TDocument-Test.vala"
		_g_error_free0 (e);
#line 1670 "SerializableObjectModel-TDocument-Test.c"
	}
	__finally341:
#line 150 "SerializableObjectModel-TDocument-Test.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 150 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (monitor);
#line 150 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (doc);
#line 150 "SerializableObjectModel-TDocument-Test.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 150 "SerializableObjectModel-TDocument-Test.vala"
		g_clear_error (&_inner_error0_);
#line 150 "SerializableObjectModel-TDocument-Test.vala"
		return;
#line 1685 "SerializableObjectModel-TDocument-Test.c"
	}
#line 147 "SerializableObjectModel-TDocument-Test.vala"
	_g_object_unref0 (monitor);
#line 147 "SerializableObjectModel-TDocument-Test.vala"
	_g_object_unref0 (doc);
#line 1691 "SerializableObjectModel-TDocument-Test.c"
}

static void
___lambda287__gtest_func (void)
{
#line 146 "SerializableObjectModel-TDocument-Test.vala"
	__lambda287_ ();
#line 1699 "SerializableObjectModel-TDocument-Test.c"
}

static void
__lambda288_ (void)
{
	GXmlTDocument* doc = NULL;
	GXmlTDocument* _tmp0_;
	Configuration* configuration = NULL;
	Configuration* _tmp1_;
	GError* _inner_error0_ = NULL;
#line 243 "SerializableObjectModel-TDocument-Test.vala"
	_tmp0_ = gxml_tdocument_new ();
#line 243 "SerializableObjectModel-TDocument-Test.vala"
	doc = _tmp0_;
#line 244 "SerializableObjectModel-TDocument-Test.vala"
	_tmp1_ = configuration_new ();
#line 244 "SerializableObjectModel-TDocument-Test.vala"
	configuration = _tmp1_;
#line 245 "SerializableObjectModel-TDocument-Test.vala"
	configuration_set_device (configuration, "Controller");
#line 1720 "SerializableObjectModel-TDocument-Test.c"
	{
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlNode* _tmp5_;
		GXmlNode* _tmp6_;
		gboolean _tmp7_;
		GXmlElement* element = NULL;
		GXmlNode* _tmp8_;
		GXmlNode* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		gchar* _tmp12_;
		gboolean _tmp13_;
		gboolean found = FALSE;
#line 247 "SerializableObjectModel-TDocument-Test.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) configuration, (GXmlNode*) doc, &_inner_error0_);
#line 247 "SerializableObjectModel-TDocument-Test.vala"
		_tmp3_ = _tmp2_;
#line 247 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp3_);
#line 247 "SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 1744 "SerializableObjectModel-TDocument-Test.c"
			goto __catch342_g_error;
		}
#line 249 "SerializableObjectModel-TDocument-Test.vala"
		_tmp4_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 249 "SerializableObjectModel-TDocument-Test.vala"
		_tmp5_ = _tmp4_;
#line 249 "SerializableObjectModel-TDocument-Test.vala"
		_tmp6_ = _tmp5_;
#line 249 "SerializableObjectModel-TDocument-Test.vala"
		_tmp7_ = _tmp6_ == NULL;
#line 249 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp6_);
#line 249 "SerializableObjectModel-TDocument-Test.vala"
		if (_tmp7_) {
#line 253 "SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1761 "SerializableObjectModel-TDocument-Test.c"
		}
#line 255 "SerializableObjectModel-TDocument-Test.vala"
		_tmp8_ = gxml_document_get_root ((GXmlDocument*) doc);
#line 255 "SerializableObjectModel-TDocument-Test.vala"
		_tmp9_ = _tmp8_;
#line 255 "SerializableObjectModel-TDocument-Test.vala"
		element = G_TYPE_CHECK_INSTANCE_CAST (_tmp9_, GXML_TYPE_ELEMENT, GXmlElement);
#line 256 "SerializableObjectModel-TDocument-Test.vala"
		_tmp10_ = gxml_node_get_name ((GXmlNode*) element);
#line 256 "SerializableObjectModel-TDocument-Test.vala"
		_tmp11_ = _tmp10_;
#line 256 "SerializableObjectModel-TDocument-Test.vala"
		_tmp12_ = _tmp11_;
#line 256 "SerializableObjectModel-TDocument-Test.vala"
		_tmp13_ = g_strcmp0 (_tmp12_, "Configuration") != 0;
#line 256 "SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp12_);
#line 256 "SerializableObjectModel-TDocument-Test.vala"
		if (_tmp13_) {
#line 260 "SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1783 "SerializableObjectModel-TDocument-Test.c"
		}
#line 262 "SerializableObjectModel-TDocument-Test.vala"
		found = FALSE;
#line 1787 "SerializableObjectModel-TDocument-Test.c"
		{
			GeeList* _n_list = NULL;
			GeeList* _tmp14_;
			GeeList* _tmp15_;
			gint _n_size = 0;
			GeeList* _tmp16_;
			gint _tmp17_;
			gint _tmp18_;
			gint _n_index = 0;
#line 263 "SerializableObjectModel-TDocument-Test.vala"
			_tmp14_ = gxml_node_get_namespaces ((GXmlNode*) element);
#line 263 "SerializableObjectModel-TDocument-Test.vala"
			_tmp15_ = _tmp14_;
#line 263 "SerializableObjectModel-TDocument-Test.vala"
			_n_list = _tmp15_;
#line 263 "SerializableObjectModel-TDocument-Test.vala"
			_tmp16_ = _n_list;
#line 263 "SerializableObjectModel-TDocument-Test.vala"
			_tmp17_ = gee_collection_get_size ((GeeCollection*) _tmp16_);
#line 263 "SerializableObjectModel-TDocument-Test.vala"
			_tmp18_ = _tmp17_;
#line 263 "SerializableObjectModel-TDocument-Test.vala"
			_n_size = _tmp18_;
#line 263 "SerializableObjectModel-TDocument-Test.vala"
			_n_index = -1;
#line 263 "SerializableObjectModel-TDocument-Test.vala"
			while (TRUE) {
#line 1815 "SerializableObjectModel-TDocument-Test.c"
				GXmlNamespace* n = NULL;
				GeeList* _tmp19_;
				gpointer _tmp20_;
				gboolean _tmp21_ = FALSE;
				GXmlNamespace* _tmp22_;
				gchar* _tmp23_;
				gchar* _tmp24_;
				gchar* _tmp25_;
				gboolean _tmp26_;
#line 263 "SerializableObjectModel-TDocument-Test.vala"
				_n_index = _n_index + 1;
#line 263 "SerializableObjectModel-TDocument-Test.vala"
				if (!(_n_index < _n_size)) {
#line 263 "SerializableObjectModel-TDocument-Test.vala"
					break;
#line 1831 "SerializableObjectModel-TDocument-Test.c"
				}
#line 263 "SerializableObjectModel-TDocument-Test.vala"
				_tmp19_ = _n_list;
#line 263 "SerializableObjectModel-TDocument-Test.vala"
				_tmp20_ = gee_list_get (_tmp19_, _n_index);
#line 263 "SerializableObjectModel-TDocument-Test.vala"
				n = (GXmlNamespace*) _tmp20_;
#line 265 "SerializableObjectModel-TDocument-Test.vala"
				_tmp22_ = n;
#line 265 "SerializableObjectModel-TDocument-Test.vala"
				_tmp23_ = gxml_namespace_get_prefix (_tmp22_);
#line 265 "SerializableObjectModel-TDocument-Test.vala"
				_tmp24_ = _tmp23_;
#line 265 "SerializableObjectModel-TDocument-Test.vala"
				_tmp25_ = _tmp24_;
#line 265 "SerializableObjectModel-TDocument-Test.vala"
				_tmp26_ = g_strcmp0 (_tmp25_, "om") == 0;
#line 265 "SerializableObjectModel-TDocument-Test.vala"
				_g_free0 (_tmp25_);
#line 265 "SerializableObjectModel-TDocument-Test.vala"
				if (_tmp26_) {
#line 1853 "SerializableObjectModel-TDocument-Test.c"
					GXmlNamespace* _tmp27_;
					gchar* _tmp28_;
					gchar* _tmp29_;
					gchar* _tmp30_;
#line 265 "SerializableObjectModel-TDocument-Test.vala"
					_tmp27_ = n;
#line 265 "SerializableObjectModel-TDocument-Test.vala"
					_tmp28_ = gxml_namespace_get_uri (_tmp27_);
#line 265 "SerializableObjectModel-TDocument-Test.vala"
					_tmp29_ = _tmp28_;
#line 265 "SerializableObjectModel-TDocument-Test.vala"
					_tmp30_ = _tmp29_;
#line 265 "SerializableObjectModel-TDocument-Test.vala"
					_tmp21_ = g_strcmp0 (_tmp30_, "http://www.gnome.org/gxml/0.4") == 0;
#line 265 "SerializableObjectModel-TDocument-Test.vala"
					_g_free0 (_tmp30_);
#line 1870 "SerializableObjectModel-TDocument-Test.c"
				} else {
#line 265 "SerializableObjectModel-TDocument-Test.vala"
					_tmp21_ = FALSE;
#line 1874 "SerializableObjectModel-TDocument-Test.c"
				}
#line 265 "SerializableObjectModel-TDocument-Test.vala"
				if (_tmp21_) {
#line 266 "SerializableObjectModel-TDocument-Test.vala"
					found = TRUE;
#line 1880 "SerializableObjectModel-TDocument-Test.c"
				}
#line 263 "SerializableObjectModel-TDocument-Test.vala"
				_g_object_unref0 (n);
#line 1884 "SerializableObjectModel-TDocument-Test.c"
			}
#line 263 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (_n_list);
#line 1888 "SerializableObjectModel-TDocument-Test.c"
		}
#line 268 "SerializableObjectModel-TDocument-Test.vala"
		if (!found) {
#line 275 "SerializableObjectModel-TDocument-Test.vala"
			g_assert_not_reached ();
#line 1894 "SerializableObjectModel-TDocument-Test.c"
		}
#line 246 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (element);
#line 1898 "SerializableObjectModel-TDocument-Test.c"
	}
	goto __finally342;
	__catch342_g_error:
	{
		GError* e = NULL;
		FILE* _tmp31_;
		const gchar* _tmp32_;
		const gchar* _tmp33_;
		gchar* _tmp34_;
		gchar* _tmp35_;
#line 246 "SerializableObjectModel-TDocument-Test.vala"
		e = _inner_error0_;
#line 246 "SerializableObjectModel-TDocument-Test.vala"
		_inner_error0_ = NULL;
#line 279 "SerializableObjectModel-TDocument-Test.vala"
		_tmp31_ = stdout;
#line 279 "SerializableObjectModel-TDocument-Test.vala"
		_tmp32_ = e->message;
#line 279 "SerializableObjectModel-TDocument-Test.vala"
		_tmp33_ = string_to_string (_tmp32_);
#line 279 "SerializableObjectModel-TDocument-Test.vala"
		_tmp34_ = g_strconcat ("Error: ", _tmp33_, NULL);
#line 279 "SerializableObjectModel-TDocument-Test.vala"
		_tmp35_ = _tmp34_;
#line 279 "SerializableObjectModel-TDocument-Test.vala"
		fprintf (_tmp31_, "%s", _tmp35_);
#line 279 "SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp35_);
#line 280 "SerializableObjectModel-TDocument-Test.vala"
		g_assert_not_reached ();
#line 246 "SerializableObjectModel-TDocument-Test.vala"
		_g_error_free0 (e);
#line 1931 "SerializableObjectModel-TDocument-Test.c"
	}
	__finally342:
#line 246 "SerializableObjectModel-TDocument-Test.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 246 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (configuration);
#line 246 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (doc);
#line 246 "SerializableObjectModel-TDocument-Test.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 246 "SerializableObjectModel-TDocument-Test.vala"
		g_clear_error (&_inner_error0_);
#line 246 "SerializableObjectModel-TDocument-Test.vala"
		return;
#line 1946 "SerializableObjectModel-TDocument-Test.c"
	}
#line 242 "SerializableObjectModel-TDocument-Test.vala"
	_g_object_unref0 (configuration);
#line 242 "SerializableObjectModel-TDocument-Test.vala"
	_g_object_unref0 (doc);
#line 1952 "SerializableObjectModel-TDocument-Test.c"
}

static void
___lambda288__gtest_func (void)
{
#line 241 "SerializableObjectModel-TDocument-Test.vala"
	__lambda288_ ();
#line 1960 "SerializableObjectModel-TDocument-Test.c"
}

static gboolean
string_contains (const gchar* self,
                 const gchar* needle)
{
	gboolean result = FALSE;
	gchar* _tmp0_;
#line 1476 "glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, FALSE);
#line 1476 "glib-2.0.vapi"
	g_return_val_if_fail (needle != NULL, FALSE);
#line 1477 "glib-2.0.vapi"
	_tmp0_ = strstr ((gchar*) self, (gchar*) needle);
#line 1477 "glib-2.0.vapi"
	result = _tmp0_ != NULL;
#line 1477 "glib-2.0.vapi"
	return result;
#line 1979 "SerializableObjectModel-TDocument-Test.c"
}

static void
__lambda289_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		NameSpace* ns = NULL;
		NameSpace* _tmp0_;
		GXmlTDocument* doc = NULL;
		GXmlTDocument* _tmp1_;
		GXmlNode* _tmp2_;
		GXmlNode* _tmp3_;
		gchar* str = NULL;
		gchar* _tmp4_;
#line 285 "SerializableObjectModel-TDocument-Test.vala"
		_tmp0_ = name_space_new ();
#line 285 "SerializableObjectModel-TDocument-Test.vala"
		ns = _tmp0_;
#line 286 "SerializableObjectModel-TDocument-Test.vala"
		_tmp1_ = gxml_tdocument_new ();
#line 286 "SerializableObjectModel-TDocument-Test.vala"
		doc = _tmp1_;
#line 287 "SerializableObjectModel-TDocument-Test.vala"
		_tmp2_ = gxml_serializable_object_model_serialize ((GXmlSerializableObjectModel*) ns, (GXmlNode*) doc, &_inner_error0_);
#line 287 "SerializableObjectModel-TDocument-Test.vala"
		_tmp3_ = _tmp2_;
#line 287 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp3_);
#line 287 "SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 287 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (doc);
#line 287 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (ns);
#line 2015 "SerializableObjectModel-TDocument-Test.c"
			goto __catch343_g_error;
		}
#line 288 "SerializableObjectModel-TDocument-Test.vala"
		_tmp4_ = gxml_tnode_to_string ((GXmlTNode*) doc);
#line 288 "SerializableObjectModel-TDocument-Test.vala"
		str = _tmp4_;
#line 292 "SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (string_contains (str, "<namespace xmlns:gxml=\"http://www.gnome.org/GXml\"/>"), "\"<namespace xmlns:gxml=\\\"http://www.gnome.org/GXml\\\"/>\" in str");
#line 284 "SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (str);
#line 284 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (doc);
#line 284 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (ns);
#line 2030 "SerializableObjectModel-TDocument-Test.c"
	}
	goto __finally343;
	__catch343_g_error:
	{
		GError* e = NULL;
#line 284 "SerializableObjectModel-TDocument-Test.vala"
		e = _inner_error0_;
#line 284 "SerializableObjectModel-TDocument-Test.vala"
		_inner_error0_ = NULL;
#line 297 "SerializableObjectModel-TDocument-Test.vala"
		g_assert_not_reached ();
#line 284 "SerializableObjectModel-TDocument-Test.vala"
		_g_error_free0 (e);
#line 2044 "SerializableObjectModel-TDocument-Test.c"
	}
	__finally343:
#line 284 "SerializableObjectModel-TDocument-Test.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 284 "SerializableObjectModel-TDocument-Test.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 284 "SerializableObjectModel-TDocument-Test.vala"
		g_clear_error (&_inner_error0_);
#line 284 "SerializableObjectModel-TDocument-Test.vala"
		return;
#line 2055 "SerializableObjectModel-TDocument-Test.c"
	}
}

static void
___lambda289__gtest_func (void)
{
#line 283 "SerializableObjectModel-TDocument-Test.vala"
	__lambda289_ ();
#line 2064 "SerializableObjectModel-TDocument-Test.c"
}

static gpointer
_g_object_ref0 (gpointer self)
{
#line 304 "SerializableObjectModel-TDocument-Test.vala"
	return self ? g_object_ref (self) : NULL;
#line 2072 "SerializableObjectModel-TDocument-Test.c"
}

static void
__lambda290_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		Package* p = NULL;
		Package* _tmp0_;
		GXmlTDocument* doc = NULL;
		GXmlTDocument* _tmp1_;
		GXmlNode* _tmp2_ = NULL;
		GXmlTDocument* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlElement* r = NULL;
		GXmlElement* _tmp5_;
		GXmlTDocument* _tmp6_;
		GeeBidirList* _tmp7_;
		GeeBidirList* _tmp8_;
		GeeBidirList* _tmp9_;
		GXmlElement* _tmp10_;
		GXmlElement* _tmp11_;
		GXmlElement* _tmp12_;
		GXmlElement* _tmp13_;
		Package* _tmp14_;
		GXmlTDocument* _tmp15_;
		Package* _tmp16_;
		GeeMap* _tmp17_;
		GeeMap* _tmp18_;
		GeeMap* _tmp19_;
		GXmlAttribute* ukattr = NULL;
		Package* _tmp20_;
		GeeMap* _tmp21_;
		GeeMap* _tmp22_;
		GeeMap* _tmp23_;
		gpointer _tmp24_;
		GXmlAttribute* _tmp25_;
		gchar* _tmp26_;
		gchar* _tmp27_;
		gchar* _tmp28_;
		gchar* _tmp29_;
		gchar* _tmp30_;
		gchar* _tmp31_;
#line 302 "SerializableObjectModel-TDocument-Test.vala"
		_tmp0_ = package_new ();
#line 302 "SerializableObjectModel-TDocument-Test.vala"
		p = _tmp0_;
#line 303 "SerializableObjectModel-TDocument-Test.vala"
		_tmp1_ = gxml_tdocument_new ();
#line 303 "SerializableObjectModel-TDocument-Test.vala"
		doc = _tmp1_;
#line 304 "SerializableObjectModel-TDocument-Test.vala"
		_tmp3_ = doc;
#line 304 "SerializableObjectModel-TDocument-Test.vala"
		_tmp4_ = gxml_document_create_element ((GXmlDocument*) _tmp3_, "PACKAGE", &_inner_error0_);
#line 304 "SerializableObjectModel-TDocument-Test.vala"
		_tmp2_ = _tmp4_;
#line 304 "SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 304 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (doc);
#line 304 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (p);
#line 2136 "SerializableObjectModel-TDocument-Test.c"
			goto __catch344_g_error;
		}
#line 304 "SerializableObjectModel-TDocument-Test.vala"
		_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GXML_TYPE_ELEMENT, GXmlElement));
#line 304 "SerializableObjectModel-TDocument-Test.vala"
		r = _tmp5_;
#line 305 "SerializableObjectModel-TDocument-Test.vala"
		_tmp6_ = doc;
#line 305 "SerializableObjectModel-TDocument-Test.vala"
		_tmp7_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp6_);
#line 305 "SerializableObjectModel-TDocument-Test.vala"
		_tmp8_ = _tmp7_;
#line 305 "SerializableObjectModel-TDocument-Test.vala"
		_tmp9_ = _tmp8_;
#line 305 "SerializableObjectModel-TDocument-Test.vala"
		_tmp10_ = r;
#line 305 "SerializableObjectModel-TDocument-Test.vala"
		gee_collection_add ((GeeCollection*) _tmp9_, (GXmlNode*) _tmp10_);
#line 305 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp9_);
#line 306 "SerializableObjectModel-TDocument-Test.vala"
		_tmp11_ = r;
#line 306 "SerializableObjectModel-TDocument-Test.vala"
		gxml_element_set_attr (_tmp11_, "source", "Mexico/North");
#line 307 "SerializableObjectModel-TDocument-Test.vala"
		_tmp12_ = r;
#line 307 "SerializableObjectModel-TDocument-Test.vala"
		gxml_element_set_attr (_tmp12_, "destiny", "Brazil");
#line 308 "SerializableObjectModel-TDocument-Test.vala"
		_tmp13_ = r;
#line 308 "SerializableObjectModel-TDocument-Test.vala"
		gxml_element_set_attr (_tmp13_, "Unknown", "2/4.04");
#line 309 "SerializableObjectModel-TDocument-Test.vala"
		_tmp14_ = p;
#line 309 "SerializableObjectModel-TDocument-Test.vala"
		_tmp15_ = doc;
#line 309 "SerializableObjectModel-TDocument-Test.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp14_, (GXmlNode*) _tmp15_, &_inner_error0_);
#line 309 "SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 309 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (r);
#line 309 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (_tmp2_);
#line 309 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (doc);
#line 309 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (p);
#line 2185 "SerializableObjectModel-TDocument-Test.c"
			goto __catch344_g_error;
		}
#line 310 "SerializableObjectModel-TDocument-Test.vala"
		_tmp16_ = p;
#line 310 "SerializableObjectModel-TDocument-Test.vala"
		_tmp17_ = gxml_serializable_get_unknown_serializable_properties ((GXmlSerializable*) _tmp16_);
#line 310 "SerializableObjectModel-TDocument-Test.vala"
		_tmp18_ = _tmp17_;
#line 310 "SerializableObjectModel-TDocument-Test.vala"
		_tmp19_ = _tmp18_;
#line 310 "SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (_tmp19_ != NULL, "p.unknown_serializable_properties != null");
#line 310 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp19_);
#line 311 "SerializableObjectModel-TDocument-Test.vala"
		_tmp20_ = p;
#line 311 "SerializableObjectModel-TDocument-Test.vala"
		_tmp21_ = gxml_serializable_get_unknown_serializable_properties ((GXmlSerializable*) _tmp20_);
#line 311 "SerializableObjectModel-TDocument-Test.vala"
		_tmp22_ = _tmp21_;
#line 311 "SerializableObjectModel-TDocument-Test.vala"
		_tmp23_ = _tmp22_;
#line 311 "SerializableObjectModel-TDocument-Test.vala"
		_tmp24_ = gee_map_get (_tmp23_, "Unknown");
#line 311 "SerializableObjectModel-TDocument-Test.vala"
		_tmp25_ = (GXmlAttribute*) _tmp24_;
#line 311 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp23_);
#line 311 "SerializableObjectModel-TDocument-Test.vala"
		ukattr = _tmp25_;
#line 312 "SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (ukattr != NULL, "ukattr != null");
#line 313 "SerializableObjectModel-TDocument-Test.vala"
		_tmp26_ = gxml_node_get_name ((GXmlNode*) ukattr);
#line 313 "SerializableObjectModel-TDocument-Test.vala"
		_tmp27_ = _tmp26_;
#line 313 "SerializableObjectModel-TDocument-Test.vala"
		_tmp28_ = _tmp27_;
#line 313 "SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (g_strcmp0 (_tmp28_, "Unknown") == 0, "ukattr.name == \"Unknown\"");
#line 313 "SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp28_);
#line 314 "SerializableObjectModel-TDocument-Test.vala"
		_tmp29_ = gxml_node_get_value ((GXmlNode*) ukattr);
#line 314 "SerializableObjectModel-TDocument-Test.vala"
		_tmp30_ = _tmp29_;
#line 314 "SerializableObjectModel-TDocument-Test.vala"
		_tmp31_ = _tmp30_;
#line 314 "SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (g_strcmp0 (_tmp31_, "2/4.04") == 0, "ukattr.value == \"2/4.04\"");
#line 314 "SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp31_);
#line 301 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (ukattr);
#line 301 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (r);
#line 301 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp2_);
#line 301 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (doc);
#line 301 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (p);
#line 2248 "SerializableObjectModel-TDocument-Test.c"
	}
	goto __finally344;
	__catch344_g_error:
	{
		GError* e = NULL;
#line 301 "SerializableObjectModel-TDocument-Test.vala"
		e = _inner_error0_;
#line 301 "SerializableObjectModel-TDocument-Test.vala"
		_inner_error0_ = NULL;
#line 319 "SerializableObjectModel-TDocument-Test.vala"
		g_assert_not_reached ();
#line 301 "SerializableObjectModel-TDocument-Test.vala"
		_g_error_free0 (e);
#line 2262 "SerializableObjectModel-TDocument-Test.c"
	}
	__finally344:
#line 301 "SerializableObjectModel-TDocument-Test.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 301 "SerializableObjectModel-TDocument-Test.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 301 "SerializableObjectModel-TDocument-Test.vala"
		g_clear_error (&_inner_error0_);
#line 301 "SerializableObjectModel-TDocument-Test.vala"
		return;
#line 2273 "SerializableObjectModel-TDocument-Test.c"
	}
}

static void
___lambda290__gtest_func (void)
{
#line 300 "SerializableObjectModel-TDocument-Test.vala"
	__lambda290_ ();
#line 2282 "SerializableObjectModel-TDocument-Test.c"
}

static void
__lambda291_ (void)
{
	GError* _inner_error0_ = NULL;
	{
		Package* p = NULL;
		Package* _tmp0_;
		GXmlTDocument* doc = NULL;
		GXmlTDocument* _tmp1_;
		GXmlNode* _tmp2_ = NULL;
		GXmlTDocument* _tmp3_;
		GXmlNode* _tmp4_;
		GXmlElement* r = NULL;
		GXmlElement* _tmp5_;
		GXmlTDocument* _tmp6_;
		GeeBidirList* _tmp7_;
		GeeBidirList* _tmp8_;
		GeeBidirList* _tmp9_;
		GXmlElement* _tmp10_;
		GXmlElement* _tmp11_;
		GXmlElement* _tmp12_;
		GXmlNode* _tmp13_ = NULL;
		GXmlTDocument* _tmp14_;
		GXmlNode* _tmp15_;
		GXmlElement* c = NULL;
		GXmlElement* _tmp16_;
		GXmlElement* _tmp17_;
		GeeBidirList* _tmp18_;
		GeeBidirList* _tmp19_;
		GeeBidirList* _tmp20_;
		GXmlElement* _tmp21_;
		GXmlElement* _tmp22_;
		Package* _tmp23_;
		GXmlTDocument* _tmp24_;
		Package* _tmp25_;
		GeeCollection* _tmp26_;
		GeeCollection* _tmp27_;
		GeeCollection* _tmp28_;
		gboolean found = FALSE;
		GXmlNode* un = NULL;
		GXmlElement* _tmp29_;
		GXmlNode* _tmp30_;
		GXmlNode* ukattr = NULL;
		GXmlNode* _tmp47_;
		GeeMap* _tmp48_;
		GeeMap* _tmp49_;
		GeeMap* _tmp50_;
		gpointer _tmp51_;
		GXmlNode* _tmp52_;
		gchar* _tmp53_;
		gchar* _tmp54_;
		gchar* _tmp55_;
		gchar* _tmp56_;
		gchar* _tmp57_;
		gchar* _tmp58_;
#line 324 "SerializableObjectModel-TDocument-Test.vala"
		_tmp0_ = package_new ();
#line 324 "SerializableObjectModel-TDocument-Test.vala"
		p = _tmp0_;
#line 325 "SerializableObjectModel-TDocument-Test.vala"
		_tmp1_ = gxml_tdocument_new ();
#line 325 "SerializableObjectModel-TDocument-Test.vala"
		doc = _tmp1_;
#line 326 "SerializableObjectModel-TDocument-Test.vala"
		_tmp3_ = doc;
#line 326 "SerializableObjectModel-TDocument-Test.vala"
		_tmp4_ = gxml_document_create_element ((GXmlDocument*) _tmp3_, "PACKAGE", &_inner_error0_);
#line 326 "SerializableObjectModel-TDocument-Test.vala"
		_tmp2_ = _tmp4_;
#line 326 "SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 326 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (doc);
#line 326 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (p);
#line 2360 "SerializableObjectModel-TDocument-Test.c"
			goto __catch345_g_error;
		}
#line 326 "SerializableObjectModel-TDocument-Test.vala"
		_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp2_, GXML_TYPE_ELEMENT, GXmlElement));
#line 326 "SerializableObjectModel-TDocument-Test.vala"
		r = _tmp5_;
#line 327 "SerializableObjectModel-TDocument-Test.vala"
		_tmp6_ = doc;
#line 327 "SerializableObjectModel-TDocument-Test.vala"
		_tmp7_ = gxml_tnode_get_children_nodes ((GXmlTNode*) _tmp6_);
#line 327 "SerializableObjectModel-TDocument-Test.vala"
		_tmp8_ = _tmp7_;
#line 327 "SerializableObjectModel-TDocument-Test.vala"
		_tmp9_ = _tmp8_;
#line 327 "SerializableObjectModel-TDocument-Test.vala"
		_tmp10_ = r;
#line 327 "SerializableObjectModel-TDocument-Test.vala"
		gee_collection_add ((GeeCollection*) _tmp9_, (GXmlNode*) _tmp10_);
#line 327 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp9_);
#line 328 "SerializableObjectModel-TDocument-Test.vala"
		_tmp11_ = r;
#line 328 "SerializableObjectModel-TDocument-Test.vala"
		gxml_element_set_attr (_tmp11_, "source", "Mexico/North");
#line 329 "SerializableObjectModel-TDocument-Test.vala"
		_tmp12_ = r;
#line 329 "SerializableObjectModel-TDocument-Test.vala"
		gxml_element_set_attr (_tmp12_, "destiny", "Brazil");
#line 330 "SerializableObjectModel-TDocument-Test.vala"
		_tmp14_ = doc;
#line 330 "SerializableObjectModel-TDocument-Test.vala"
		_tmp15_ = gxml_document_create_element ((GXmlDocument*) _tmp14_, "Unknown", &_inner_error0_);
#line 330 "SerializableObjectModel-TDocument-Test.vala"
		_tmp13_ = _tmp15_;
#line 330 "SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 330 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (r);
#line 330 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (_tmp2_);
#line 330 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (doc);
#line 330 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (p);
#line 2405 "SerializableObjectModel-TDocument-Test.c"
			goto __catch345_g_error;
		}
#line 330 "SerializableObjectModel-TDocument-Test.vala"
		_tmp16_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp13_, GXML_TYPE_ELEMENT, GXmlElement));
#line 330 "SerializableObjectModel-TDocument-Test.vala"
		c = _tmp16_;
#line 331 "SerializableObjectModel-TDocument-Test.vala"
		_tmp17_ = r;
#line 331 "SerializableObjectModel-TDocument-Test.vala"
		_tmp18_ = gxml_node_get_children_nodes ((GXmlNode*) _tmp17_);
#line 331 "SerializableObjectModel-TDocument-Test.vala"
		_tmp19_ = _tmp18_;
#line 331 "SerializableObjectModel-TDocument-Test.vala"
		_tmp20_ = _tmp19_;
#line 331 "SerializableObjectModel-TDocument-Test.vala"
		_tmp21_ = c;
#line 331 "SerializableObjectModel-TDocument-Test.vala"
		gee_collection_add ((GeeCollection*) _tmp20_, (GXmlNode*) _tmp21_);
#line 331 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp20_);
#line 332 "SerializableObjectModel-TDocument-Test.vala"
		_tmp22_ = c;
#line 332 "SerializableObjectModel-TDocument-Test.vala"
		gxml_element_set_attr (_tmp22_, "prop", "value");
#line 333 "SerializableObjectModel-TDocument-Test.vala"
		_tmp23_ = p;
#line 333 "SerializableObjectModel-TDocument-Test.vala"
		_tmp24_ = doc;
#line 333 "SerializableObjectModel-TDocument-Test.vala"
		gxml_serializable_object_model_deserialize ((GXmlSerializableObjectModel*) _tmp23_, (GXmlNode*) _tmp24_, &_inner_error0_);
#line 333 "SerializableObjectModel-TDocument-Test.vala"
		if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 333 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (c);
#line 333 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (_tmp13_);
#line 333 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (r);
#line 333 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (_tmp2_);
#line 333 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (doc);
#line 333 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (p);
#line 2450 "SerializableObjectModel-TDocument-Test.c"
			goto __catch345_g_error;
		}
#line 334 "SerializableObjectModel-TDocument-Test.vala"
		_tmp25_ = p;
#line 334 "SerializableObjectModel-TDocument-Test.vala"
		_tmp26_ = gxml_serializable_get_unknown_serializable_nodes ((GXmlSerializable*) _tmp25_);
#line 334 "SerializableObjectModel-TDocument-Test.vala"
		_tmp27_ = _tmp26_;
#line 334 "SerializableObjectModel-TDocument-Test.vala"
		_tmp28_ = _tmp27_;
#line 334 "SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (_tmp28_ != NULL, "p.unknown_serializable_nodes != null");
#line 334 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp28_);
#line 335 "SerializableObjectModel-TDocument-Test.vala"
		found = FALSE;
#line 336 "SerializableObjectModel-TDocument-Test.vala"
		_tmp29_ = c;
#line 336 "SerializableObjectModel-TDocument-Test.vala"
		_tmp30_ = _g_object_ref0 ((GXmlNode*) _tmp29_);
#line 336 "SerializableObjectModel-TDocument-Test.vala"
		un = _tmp30_;
#line 2473 "SerializableObjectModel-TDocument-Test.c"
		{
			GeeIterator* _n_it = NULL;
			Package* _tmp31_;
			GeeCollection* _tmp32_;
			GeeCollection* _tmp33_;
			GeeCollection* _tmp34_;
			GeeIterator* _tmp35_;
			GeeIterator* _tmp36_;
#line 337 "SerializableObjectModel-TDocument-Test.vala"
			_tmp31_ = p;
#line 337 "SerializableObjectModel-TDocument-Test.vala"
			_tmp32_ = gxml_serializable_get_unknown_serializable_nodes ((GXmlSerializable*) _tmp31_);
#line 337 "SerializableObjectModel-TDocument-Test.vala"
			_tmp33_ = _tmp32_;
#line 337 "SerializableObjectModel-TDocument-Test.vala"
			_tmp34_ = _tmp33_;
#line 337 "SerializableObjectModel-TDocument-Test.vala"
			_tmp35_ = gee_iterable_iterator ((GeeIterable*) _tmp34_);
#line 337 "SerializableObjectModel-TDocument-Test.vala"
			_tmp36_ = _tmp35_;
#line 337 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (_tmp34_);
#line 337 "SerializableObjectModel-TDocument-Test.vala"
			_n_it = _tmp36_;
#line 337 "SerializableObjectModel-TDocument-Test.vala"
			while (TRUE) {
#line 2500 "SerializableObjectModel-TDocument-Test.c"
				GeeIterator* _tmp37_;
				GXmlNode* n = NULL;
				GeeIterator* _tmp38_;
				gpointer _tmp39_;
				GXmlNode* _tmp40_;
				gchar* _tmp41_;
				gchar* _tmp42_;
				gchar* _tmp43_;
				gboolean _tmp44_;
#line 337 "SerializableObjectModel-TDocument-Test.vala"
				_tmp37_ = _n_it;
#line 337 "SerializableObjectModel-TDocument-Test.vala"
				if (!gee_iterator_next (_tmp37_)) {
#line 337 "SerializableObjectModel-TDocument-Test.vala"
					break;
#line 2516 "SerializableObjectModel-TDocument-Test.c"
				}
#line 337 "SerializableObjectModel-TDocument-Test.vala"
				_tmp38_ = _n_it;
#line 337 "SerializableObjectModel-TDocument-Test.vala"
				_tmp39_ = gee_iterator_get (_tmp38_);
#line 337 "SerializableObjectModel-TDocument-Test.vala"
				n = (GXmlNode*) _tmp39_;
#line 338 "SerializableObjectModel-TDocument-Test.vala"
				_tmp40_ = n;
#line 338 "SerializableObjectModel-TDocument-Test.vala"
				_tmp41_ = gxml_node_get_name (_tmp40_);
#line 338 "SerializableObjectModel-TDocument-Test.vala"
				_tmp42_ = _tmp41_;
#line 338 "SerializableObjectModel-TDocument-Test.vala"
				_tmp43_ = _tmp42_;
#line 338 "SerializableObjectModel-TDocument-Test.vala"
				_tmp44_ = g_strcmp0 (_tmp43_, "Unknown") == 0;
#line 338 "SerializableObjectModel-TDocument-Test.vala"
				_g_free0 (_tmp43_);
#line 338 "SerializableObjectModel-TDocument-Test.vala"
				if (_tmp44_) {
#line 2538 "SerializableObjectModel-TDocument-Test.c"
					GXmlNode* _tmp45_;
					GXmlNode* _tmp46_;
#line 339 "SerializableObjectModel-TDocument-Test.vala"
					found = TRUE;
#line 340 "SerializableObjectModel-TDocument-Test.vala"
					_tmp45_ = n;
#line 340 "SerializableObjectModel-TDocument-Test.vala"
					_tmp46_ = _g_object_ref0 (_tmp45_);
#line 340 "SerializableObjectModel-TDocument-Test.vala"
					_g_object_unref0 (un);
#line 340 "SerializableObjectModel-TDocument-Test.vala"
					un = _tmp46_;
#line 2551 "SerializableObjectModel-TDocument-Test.c"
				}
#line 337 "SerializableObjectModel-TDocument-Test.vala"
				_g_object_unref0 (n);
#line 2555 "SerializableObjectModel-TDocument-Test.c"
			}
#line 337 "SerializableObjectModel-TDocument-Test.vala"
			_g_object_unref0 (_n_it);
#line 2559 "SerializableObjectModel-TDocument-Test.c"
		}
#line 343 "SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (found, "found");
#line 344 "SerializableObjectModel-TDocument-Test.vala"
		_tmp47_ = un;
#line 344 "SerializableObjectModel-TDocument-Test.vala"
		_tmp48_ = gxml_node_get_attrs (_tmp47_);
#line 344 "SerializableObjectModel-TDocument-Test.vala"
		_tmp49_ = _tmp48_;
#line 344 "SerializableObjectModel-TDocument-Test.vala"
		_tmp50_ = _tmp49_;
#line 344 "SerializableObjectModel-TDocument-Test.vala"
		_tmp51_ = gee_map_get (_tmp50_, "prop");
#line 344 "SerializableObjectModel-TDocument-Test.vala"
		_tmp52_ = (GXmlNode*) _tmp51_;
#line 344 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp50_);
#line 344 "SerializableObjectModel-TDocument-Test.vala"
		ukattr = _tmp52_;
#line 345 "SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (ukattr != NULL, "ukattr != null");
#line 346 "SerializableObjectModel-TDocument-Test.vala"
		_tmp53_ = gxml_node_get_name (ukattr);
#line 346 "SerializableObjectModel-TDocument-Test.vala"
		_tmp54_ = _tmp53_;
#line 346 "SerializableObjectModel-TDocument-Test.vala"
		_tmp55_ = _tmp54_;
#line 346 "SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (g_strcmp0 (_tmp55_, "prop") == 0, "ukattr.name == \"prop\"");
#line 346 "SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp55_);
#line 347 "SerializableObjectModel-TDocument-Test.vala"
		_tmp56_ = gxml_node_get_value (ukattr);
#line 347 "SerializableObjectModel-TDocument-Test.vala"
		_tmp57_ = _tmp56_;
#line 347 "SerializableObjectModel-TDocument-Test.vala"
		_tmp58_ = _tmp57_;
#line 347 "SerializableObjectModel-TDocument-Test.vala"
		_vala_assert (g_strcmp0 (_tmp58_, "value") == 0, "ukattr.value == \"value\"");
#line 347 "SerializableObjectModel-TDocument-Test.vala"
		_g_free0 (_tmp58_);
#line 323 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (ukattr);
#line 323 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (un);
#line 323 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (c);
#line 323 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp13_);
#line 323 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (r);
#line 323 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (_tmp2_);
#line 323 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (doc);
#line 323 "SerializableObjectModel-TDocument-Test.vala"
		_g_object_unref0 (p);
#line 2617 "SerializableObjectModel-TDocument-Test.c"
	}
	goto __finally345;
	__catch345_g_error:
	{
		GError* e = NULL;
#line 323 "SerializableObjectModel-TDocument-Test.vala"
		e = _inner_error0_;
#line 323 "SerializableObjectModel-TDocument-Test.vala"
		_inner_error0_ = NULL;
#line 352 "SerializableObjectModel-TDocument-Test.vala"
		g_assert_not_reached ();
#line 323 "SerializableObjectModel-TDocument-Test.vala"
		_g_error_free0 (e);
#line 2631 "SerializableObjectModel-TDocument-Test.c"
	}
	__finally345:
#line 323 "SerializableObjectModel-TDocument-Test.vala"
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
#line 323 "SerializableObjectModel-TDocument-Test.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error0_->message, g_quark_to_string (_inner_error0_->domain), _inner_error0_->code);
#line 323 "SerializableObjectModel-TDocument-Test.vala"
		g_clear_error (&_inner_error0_);
#line 323 "SerializableObjectModel-TDocument-Test.vala"
		return;
#line 2642 "SerializableObjectModel-TDocument-Test.c"
	}
}

static void
___lambda291__gtest_func (void)
{
#line 322 "SerializableObjectModel-TDocument-Test.vala"
	__lambda291_ ();
#line 2651 "SerializableObjectModel-TDocument-Test.c"
}

void
serializable_object_model_tdocument_test_add_tests (void)
{
#line 32 "SerializableObjectModel-TDocument-Test.vala"
	g_test_add_func ("/gxml/tw/serializable/object_model/serialize/simple_object", ___lambda283__gtest_func);
#line 55 "SerializableObjectModel-TDocument-Test.vala"
	g_test_add_func ("/gxml/tw/serializable/object_model/serialize_object_contents", ___lambda284__gtest_func);
#line 71 "SerializableObjectModel-TDocument-Test.vala"
	g_test_add_func ("/gxml/tw/serializable/object_model/serialize_serializable_properties", ___lambda285__gtest_func);
#line 100 "SerializableObjectModel-TDocument-Test.vala"
	g_test_add_func ("/gxml/tw/serializable/object_model/serialize_array_property", ___lambda286__gtest_func);
#line 146 "SerializableObjectModel-TDocument-Test.vala"
	g_test_add_func ("/gxml/tw/serializable/object_model/serialize_property_nick", ___lambda287__gtest_func);
#line 241 "SerializableObjectModel-TDocument-Test.vala"
	g_test_add_func ("/gxml/tw/serializable/object_model/override_serialize", ___lambda288__gtest_func);
#line 283 "SerializableObjectModel-TDocument-Test.vala"
	g_test_add_func ("/gxml/tw/serializable/object_model/set_namespace", ___lambda289__gtest_func);
#line 300 "SerializableObjectModel-TDocument-Test.vala"
	g_test_add_func ("/gxml/tw/serializable/object_model/find-unknown_property", ___lambda290__gtest_func);
#line 322 "SerializableObjectModel-TDocument-Test.vala"
	g_test_add_func ("/gxml/tw/serializable/object_model/find-unknown_node", ___lambda291__gtest_func);
#line 2675 "SerializableObjectModel-TDocument-Test.c"
}

SerializableObjectModelTDocumentTest*
serializable_object_model_tdocument_test_construct (GType object_type)
{
	SerializableObjectModelTDocumentTest* self = NULL;
#line 28 "SerializableObjectModel-TDocument-Test.vala"
	self = (SerializableObjectModelTDocumentTest*) gxml_test_construct (object_type);
#line 28 "SerializableObjectModel-TDocument-Test.vala"
	return self;
#line 2686 "SerializableObjectModel-TDocument-Test.c"
}

SerializableObjectModelTDocumentTest*
serializable_object_model_tdocument_test_new (void)
{
#line 28 "SerializableObjectModel-TDocument-Test.vala"
	return serializable_object_model_tdocument_test_construct (TYPE_SERIALIZABLE_OBJECT_MODEL_TDOCUMENT_TEST);
#line 2694 "SerializableObjectModel-TDocument-Test.c"
}

static void
serializable_object_model_tdocument_test_class_init (SerializableObjectModelTDocumentTestClass * klass,
                                                     gpointer klass_data)
{
#line 28 "SerializableObjectModel-TDocument-Test.vala"
	serializable_object_model_tdocument_test_parent_class = g_type_class_peek_parent (klass);
#line 2703 "SerializableObjectModel-TDocument-Test.c"
}

static void
serializable_object_model_tdocument_test_instance_init (SerializableObjectModelTDocumentTest * self,
                                                        gpointer klass)
{
}

/**
 *
 *  GXml.EnumerationTest.vala
 *
 *  Authors:
 *
 *       Daniel Espinosa <esodan@gmail.com>
 *
 *
 *  Copyright (c) 2014-2015 Daniel Espinosa
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
GType
serializable_object_model_tdocument_test_get_type (void)
{
	static volatile gsize serializable_object_model_tdocument_test_type_id__volatile = 0;
	if (g_once_init_enter (&serializable_object_model_tdocument_test_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (SerializableObjectModelTDocumentTestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) serializable_object_model_tdocument_test_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (SerializableObjectModelTDocumentTest), 0, (GInstanceInitFunc) serializable_object_model_tdocument_test_instance_init, NULL };
		GType serializable_object_model_tdocument_test_type_id;
		serializable_object_model_tdocument_test_type_id = g_type_register_static (TYPE_GXML_TEST, "SerializableObjectModelTDocumentTest", &g_define_type_info, 0);
		g_once_init_leave (&serializable_object_model_tdocument_test_type_id__volatile, serializable_object_model_tdocument_test_type_id);
	}
	return serializable_object_model_tdocument_test_type_id__volatile;
}

